@@ -28,29 +28,36 @@ class Event:
         super().__init__()
         self._type = event_type
 
-    ##  The type of event.
     @property
     def type(self) -> int:
+        """The type of event."""
+
         return self._type
 
 
-##  Mouse Event class.
-#   This class represents a mouse event. It has properties corresponding to important mouse
-#   event properties and constants for mouse buttons.
 class MouseEvent(Event):
-    ## Left mouse button.
+    """Mouse Event class.
+
+    This class represents a mouse event. It has properties corresponding to important mouse
+    event properties and constants for mouse buttons.
+    """
+
     LeftButton = "left"
+    """Left mouse button."""
     RightButton = "right"
     MiddleButton = "middle"
 
-    ##  Raise a new mouse event.
-    #   \param type The type of event. \sa Event
-    #   \param x The X coordinate of the event.
-    #   \param y The Y coordinate of the event.
-    #   \param last_x The X coordinate of the previous mouse event. Can be None. It is used to calculate deltaX.
-    #   \param last_y The Y coordinate of the previous mouse event. Cam be None. It is used to calculate deltaY.
-    #   \param buttons The buttons that are associated with this event.
     def __init__(self, event_type: int, x: int = 0, y: int = 0, last_x: int = None, last_y: int = None, buttons: List[str] = None) -> None: #pylint: disable=bad-whitespace
+        """Raise a new mouse event.
+
+        :param event_type: The type of event. :sa Event
+        :param x: The X coordinate of the event.
+        :param y: The Y coordinate of the event.
+        :param last_x: The X coordinate of the previous mouse event. Can be None. It is used to calculate deltaX.
+        :param last_y: The Y coordinate of the previous mouse event. Cam be None. It is used to calculate deltaY.
+        :param buttons: The buttons that are associated with this event.
+        """
+
         super().__init__(event_type)
         self._x = x
         self._y = y
@@ -60,88 +67,104 @@ class MouseEvent(Event):
         if buttons:
             self._buttons = buttons
 
-    ##  The X coordinate of the event.
     @property
     def x(self) -> int:
+        """The X coordinate of the event."""
+
         return self._x
 
-    ##  The Y coordinate of the event.
     @property
     def y(self) -> int:
+        """The Y coordinate of the event."""
+
         return self._y
 
-    ##  The X coordinate of the previous event.
     @property
     def lastX(self) -> Optional[int]:
+        """The X coordinate of the previous event."""
+
         return self._last_x
 
-    ##  The Y coordinate of the previous event.
     @property
     def lastY(self) -> Optional[int]:
+        """The Y coordinate of the previous event."""
+
         return self._last_y
 
-    ##  The change in X position between this event and the previous event.
     @property
     def deltaX(self) -> int:
+        """The change in X position between this event and the previous event."""
+
         if self._last_x is not None:
             return self._x - self._last_x
 
         return 0
 
-    ##  The change in Y position between this event and the previous event.
     @property
     def deltaY(self) -> int:
+        """The change in Y position between this event and the previous event."""
+
         if self._last_y is not None:
             return self._y - self._last_y
 
         return 0
 
-    ##  The list of buttons associated with this event.
     @property
     def buttons(self) -> List[str]:
+        """The list of buttons associated with this event."""
+
         return self._buttons
 
 
-##  Event relating to what's happening with the scroll wheel of a mouse.
 class WheelEvent(MouseEvent):
-    ##  Create a new scroll wheel event.
-    #
-    #   \param horizontal How far the scroll wheel scrolled horizontally, in
-    #   eighths of a degree. To the right is positive. To the left is negative.
-    #   \param vertical How far the scroll wheel scrolled vertically, in eighths
-    #   of a degree. Up is positive. Down is negative.
+    """Event relating to what's happening with the scroll wheel of a mouse."""
+
     def __init__(self, horizontal: int, vertical: int, x: int = 0, y: int = 0) -> None:
+        """Create a new scroll wheel event.
+        
+        :param horizontal: How far the scroll wheel scrolled horizontally, in
+               eighths of a degree. To the right is positive. To the left is negative.
+        :param vertical: How far the scroll wheel scrolled vertically, in eighths
+               of a degree. Up is positive. Down is negative.
+        """
+
         super().__init__(Event.MouseWheelEvent, x, y)
         self._horizontal = horizontal
         self._vertical = vertical
 
-    ##  How far the scroll wheel was scrolled horizontally, in eighths of a
-    #   degree.
-    #
-    #   To the right is positive. To the left is negative.
     @property
     def horizontal(self) -> int:
+        """How far the scroll wheel was scrolled horizontally, in eighths of a
+        degree.
+        
+        To the right is positive. To the left is negative.
+        """
+
         return self._horizontal
 
-    ##  How far the scroll wheel was scrolled vertically, in eighths of a
-    #   degree.
-    #
-    #   Up is positive. Down is negative.
     @property
     def vertical(self) -> int:
+        """How far the scroll wheel was scrolled vertically, in eighths of a
+        degree.
+        
+        Up is positive. Down is negative.
+        """
+
         return self._vertical
 
 
-##  Event regarding the keyboard.
-#
-#   These events are raised when anything changes in the keyboard state. They
-#   keep track of the event type that was given by Qt, for instance whether it
-#   was a KeyPressEvent or a KeyReleaseEvent, and they keep track of which key
-#   it was.
-#
-#   Only the special keys are tracked (Shirt, Space, Escape, etc.), not the
-#   normal letter keys.
 class KeyEvent(Event):
+    """Event regarding the keyboard.
+    
+    These events are raised when anything changes in the keyboard state. They
+    keep track of the event type that was given by Qt, for instance whether it
+    was a KeyPressEvent or a KeyReleaseEvent, and they keep track of which key
+    it was.
+    
+    Only the special keys are tracked (Shirt, Space, Escape, etc.), not the
+    normal letter keys.
+    """
+
     ShiftKey = 1
     ControlKey = 2
     AltKey = 3
@@ -158,27 +181,33 @@ class KeyEvent(Event):
     PlusKey = 14
     EqualKey = 15
 
-    ##  Creates a new key event, passing the event type on to the ``Event``
-    #   parent class.
     def __init__(self, event_type: int, key: int) -> None:
+        """Creates a new key event, passing the event type on to the `Event`
+        parent class.
+        """
+
         super().__init__(event_type)
         self._key = key
 
-    ##  Which key was pressed.
-    #
-    #   Compare this with ``KeyEvent.AltKey``, ``KeyEvent.EnterKey``, etc.
     @property
     def key(self) -> int:
+        """Which key was pressed.
+        
+        Compare this with `KeyEvent.AltKey`, `KeyEvent.EnterKey`, etc.
+        """
+
         return self._key
 
 
-##  Tool related event class.
 class ToolEvent(Event):
+    """Tool related event class."""
+
     pass
 
 
-##  Event used to call a function.
 class CallFunctionEvent(Event):
+    """Event used to call a function."""
+
     def __init__(self, func: Callable[..., Any], args: Any, kwargs: Any) -> None:
         super().__init__(Event.CallFunctionEvent)
         self._function = func
@@ -189,6 +218,7 @@ class CallFunctionEvent(Event):
         self._function(*self._args, **self._kwargs)
 
 
-##  View related event class.
 class ViewEvent(Event):
+    """View related event class."""
+
     pass
