@@ -14,9 +14,9 @@ from UM.i18n import i18nCatalog
 i18n_catalog = i18nCatalog("uranium")
 
 
-##  A Job subclass that performs file loading.
-#
 class ReadFileJob(Job):
+    """A Job subclass that performs file loading."""
+
     def __init__(self, filename: str, handler: Optional[FileHandler] = None) -> None:
         super().__init__()
         self._filename = filename
