@@ -5,20 +5,26 @@ import os.path
 from PyQt5.QtCore import QMimeDatabase, QMimeType
 from typing import cast, List, Optional
 
-##  Raised when a MIME type can not be found.
+
 class MimeTypeNotFoundError(Exception):
+    """Raised when a MIME type can not be found."""
+
     pass
 
-##  Simple value type class that encapsulates MIME type data.
+
 class MimeType:
-    ##  Constructor
-    #
-    #   \param name The MIME type name, like "text/plain".
-    #   \param comment A description of the MIME type.
-    #   \param suffixes A list of possible suffixes for the type.
-    #   \param preferred_suffix The preferred suffix for the type. Defaults to
-    #   ``suffixes[0]`` if not specified.
+    """Simple value type class that encapsulates MIME type data."""
+
     def __init__(self, name: str, comment: str, suffixes: Optional[List[str]], preferred_suffix: str = None) -> None:
+        """Constructor
+        
+        :param name: The MIME type name, like "text/plain".
+        :param comment: A description of the MIME type.
+        :param suffixes: A list of possible suffixes for the type.
+        :param preferred_suffix: The preferred suffix for the type. Defaults to
+            ``suffixes[0]`` if not specified.
+        """
+
         if name is None:
             raise ValueError("Name cannot be None")
 
@@ -39,52 +45,68 @@ class MimeType:
         else:
             self.__preferred_suffix = ""
 
-    ##  The name that identifies the MIME type.
     @property
     def name(self) -> str:
+        """The name that identifies the MIME type."""
+
         return self.__name
 
-    ##  The comment that describes of the MIME type.
     @property
     def comment(self) -> str:
+        """The comment that describes of the MIME type."""
+
         return self.__comment
 
-    ##  The list of file name suffixes for the MIME type.
     @property
     def suffixes(self) -> List[str]:
+        """The list of file name suffixes for the MIME type.
+        
+        Example: ["cfg", "tar.gz"]
+        """
+
         return self.__suffixes
 
-    ##  The preferred file name suffix for the MIME type.
     @property
     def preferredSuffix(self) -> str:
+        """The preferred file name suffix for the MIME type.
+        
+        Example: "cfg" or "tar.gz".
+        """
+
         return self.__preferred_suffix
 
-    ##  Gives a programmer-readable representation of the MIME type.
-    #
-    #   \return A string representing the MIME type.
     def __repr__(self) -> str:
+        """Gives a programmer-readable representation of the MIME type.
+        
+        :return: A string representing the MIME type.
+        """
+
         return "<MimeType name={0}>".format(self.__name)
 
-    ##  Indicates whether this MIME type is equal to another MIME type.
-    #
-    #   They are equal if the names match, since MIME types should have unique
-    #   names.
-    #
-    #   \return ``True`` if the two MIME types are equal, or ``False``
-    #   otherwise.
     def __eq__(self, other: object) -> bool:
+        """Indicates whether this MIME type is equal to another MIME type.
+        
+        They are equal if the names match, since MIME types should have unique
+        names.
+        
+        :return: ``True`` if the two MIME types are equal, or ``False``
+        otherwise.
+        """
+
         if type(other) is not type(self):
             return False
         other = cast(MimeType, other)
         return self.__name == other.name
 
-    ##  Strip the extension from a file name when it corresponds to one of the
-    #   suffixes of this MIME type.
-    #
-    #   \param file_name The file name to strip of extension.
-    #   \return ``file_name`` without extension, or ``file_name`` when it does
-    #   not match.
     def stripExtension(self, file_name: str) -> str:
+        """Strip the extension from a file name when it corresponds to one of the
+        suffixes of this MIME type.
+        
+        :param file_name: The file name to strip of extension.
+        :return: ``file_name`` without extension, or ``file_name`` when it does
+        not match.
+        """
+
         for suffix in self.__suffixes:
             suffix = suffix.lower()
             if file_name.lower().endswith(suffix, file_name.find(".")):
@@ -94,13 +116,15 @@ class MimeType:
         return file_name
 
 
-    ##  Create a ``MimeType`` object from a ``QMimeType`` object.
-    #
-    #   \param qt_mime The ``QMimeType`` object to convert.
-    #   \return A new ``MimeType`` object with properties equal to the
-    #   ``QMimeType`` object.
     @staticmethod
     def fromQMimeType(qt_mime: QMimeType) -> "MimeType":
+        """Create a ``MimeType`` object from a ``QMimeType`` object.
+        
+        :param qt_mime: The ``QMimeType`` object to convert.
+        :return: A new ``MimeType`` object with properties equal to the
+            ``QMimeType`` object.
+        """
+
         return MimeType(
             name = qt_mime.name(),
             comment = qt_mime.comment(),
@@ -108,25 +132,29 @@ class MimeType:
             preferred_suffix = qt_mime.preferredSuffix()
         )
 
-##  Handles lookup of MIME types for files with support for custom MIME types.
-#
-#   This class wraps around ``QMimeDatabase`` and extends it with support for
-#   custom MIME types defined at runtime.
-#
-#   \note Custom MIME types are currently only detected based on extension.
+
 class MimeTypeDatabase:
-    ##  Get a MIME type by name.
-    #
-    #   This will return a ``MimeType`` object corresponding to the specified
-    #   name.
-    #
-    #   \param name The name of the MIME type to return.
-    #   \return A ``MimeType`` object corresponding to the specified name.
-    #
-    #   \exception MimeTypeNotFoundError Raised when the specified MIME type
-    #   cannot be found.
+    """Handles lookup of MIME types for files with support for custom MIME types.
+    
+    This class wraps around ``QMimeDatabase`` and extends it with support for
+    custom MIME types defined at runtime.
+    
+    :note Custom MIME types are currently only detected based on extension.
+    """
+
     @classmethod
     def getMimeType(cls, name: str) -> MimeType:
+        """Get a MIME type by name.
+        
+        This will return a ``MimeType`` object corresponding to the specified
+        name.
+        
+        :param name: The name of the MIME type to return.
+        :return: A ``MimeType`` object corresponding to the specified name.
+        :exception MimeTypeNotFoundError Raised when the specified MIME type
+        cannot be found.
+        """
+
         for custom_mime in cls.__custom_mimetypes:
             if custom_mime.name == name:
                 return custom_mime
@@ -139,15 +167,16 @@ class MimeTypeDatabase:
 
     MimeTypeNotFoundError = MimeTypeNotFoundError
 
-    ##  Get a MIME type for a specific file.
-    #
-    #   \param file_name The name of the file to get the MIME type for.
-    #   \return A MimeType object that contains the detected MIME type for the
-    #   file.
-    #   \exception MimeTypeNotFoundError Raised when no MIME type can be found
-    #   for the specified file.
     @classmethod
     def getMimeTypeForFile(cls, file_name: str) -> MimeType:
+        """Get a MIME type for a specific file.
+        
+        :param file_name: The name of the file to get the MIME type for.
+        :return: A MimeType object that contains the detected MIME type for the file.
+        :exception MimeTypeNotFoundError Raised when no MIME type can be found
+            for the specified file.
+        """
+
         # Properly normalize the file name to only be the base name of a path if we pass a path.
         file_name = os.path.basename(file_name)
 
@@ -176,11 +205,13 @@ class MimeTypeDatabase:
 
         raise MimeTypeNotFoundError("Could not find a valid MIME type for {0}".format(file_name))
 
-    ##  Add a custom MIME type that can be detected.
-    #
-    #   \param mime_type The custom MIME type to add.
     @classmethod
     def addMimeType(cls, mime_type: MimeType) -> None:
+        """Add a custom MIME type that can be detected.
+        
+        :param mime_type: The custom MIME type to add.
+        """
+
         cls.__custom_mimetypes.append(mime_type)
 
     @classmethod
