@@ -2,7 +2,6 @@
 # Uranium is released under the terms of the LGPLv3 or higher.
 
 from PyQt5.QtCore import QObject, pyqtProperty, pyqtSignal, pyqtSlot
-from PyQt5.QtQml import QQmlEngine, QJSEngine #For typing.
 from typing import List, Mapping, Optional, TYPE_CHECKING
 
 from UM.Application import Application
@@ -15,11 +14,13 @@ from UM.Scene.SceneNode import SceneNode
 from UM.Scene.Selection import Selection
 
 if TYPE_CHECKING:
+    from PyQt5.QtQml import QQmlEngine, QJSEngine
     from UM.FileHandler.FileHandler import FileHandler
     from UM.OutputDevice.OutputDeviceManager import OutputDeviceManager
 
 catalog = i18nCatalog("uranium")
 
+
 class OutputDeviceManagerProxy(QObject):
     def __init__(self, parent = None) -> None:
         super().__init__(parent)
@@ -53,19 +54,29 @@ class OutputDeviceManagerProxy(QObject):
     def activeDeviceDescription(self) -> str:
         return self._device_manager.getActiveDevice().getDescription()
 
-    ##  Request that the current scene is written to the output device.
-    #
-    #   The output device to write with will be selected based on the device_id.
-    #   A file format is chosen from the list of available file formats by the
-    #   output device.
-    #
-    #   \param device_id The handle of the device to write to.
-    #   \param file_name A suggestion for the file name to write
-    #   to. Can be freely ignored if providing a file name makes no sense.
-    #   \param kwargs Keyword arguments:
-    #       limit_mimetypes: Limit the possible mimetypes to use for writing to these types.
+    @pyqtSlot()
+    def startDiscovery(self) -> None:
+        return self._device_manager.startDiscovery()
+
+    @pyqtSlot()
+    def refreshConnections(self) -> None:
+        return self._device_manager.refreshConnections()
+
     @pyqtSlot(str, str, "QVariantMap")
     def requestWriteToDevice(self, device_id: str, file_name: str, kwargs: Mapping[str, str]) -> None:
+        """Request that the current scene is written to the output device.
+        
+        The output device to write with will be selected based on the device_id.
+        A file format is chosen from the list of available file formats by the
+        output device.
+        
+        :param device_id: The handle of the device to write to.
+        :param file_name: A suggestion for the file name to write
+        to. Can be freely ignored if providing a file name makes no sense.
+        :param kwargs: Keyword arguments:
+        limit_mimetypes: Limit the possible mimetypes to use for writing to these types.
+        """
+
         limit_mimetypes = kwargs.get("limit_mimetypes", None)
         file_type = kwargs.get("file_type", "mesh")
         preferred_mimetypes = kwargs.get("preferred_mimetypes", None)
@@ -74,19 +85,21 @@ class OutputDeviceManagerProxy(QObject):
         # loop, since that does work.
         Application.getInstance().callLater(self._writeToDevice, [Application.getInstance().getController().getScene().getRoot()], device_id, file_name, limit_mimetypes, file_type, preferred_mimetypes = preferred_mimetypes)
 
-    ##  Request that the current selection is written to the output device.
-    #
-    #   The output device to write with will be selected based on the device_id.
-    #   A file format is chosen from the list of available file formats by the
-    #   output device.
-    #
-    #   \param device_id The handle of the device to write to.
-    #   \param file_name A suggestion for the file name to write
-    #   to. Can be freely ignored if providing a file name makes no sense.
-    #   \param kwargs Keyword arguments:
-    #       limit_mimetypes: Limit the possible mimetypes to use for writing to these types.
     @pyqtSlot(str, str, "QVariantMap")
     def requestWriteSelectionToDevice(self, device_id: str, file_name: str, kwargs: Mapping[str, str]) -> None:
+        """Request that the current selection is written to the output device.
+        
+        The output device to write with will be selected based on the device_id.
+        A file format is chosen from the list of available file formats by the
+        output device.
+        
+        :param device_id: The handle of the device to write to.
+        :param file_name: A suggestion for the file name to write
+        to. Can be freely ignored if providing a file name makes no sense.
+        :param kwargs: Keyword arguments:
+            limit_mimetypes: Limit the possible mimetypes to use for writing to these types.
+        """
+
         if not Selection.hasSelection():
             return
 
@@ -100,19 +113,21 @@ class OutputDeviceManagerProxy(QObject):
     def _onActiveDeviceChanged(self) -> None:
         self.activeDeviceChanged.emit()
 
-    ##  Writes the specified node to the output device.
-    #
-    #   The output device to write with will be selected based on the device_id.
-    #   A file format is chosen from the list of available file formats by the
-    #   output device.
-    #
-    #   \param nodes The scene nodes that must be written to the device.
-    #   \param device_id The handle of the device to write to.
-    #   \param file_name A suggestion for the file name to write
-    #   to. Can be freely ignored if providing a file name makes no sense.
-    #   \param limit_mimetypes: Limit the possible mimetypes to use for writing to these types.
-    #   \param file_type What file handler to get the writer from.
     def _writeToDevice(self, nodes: List[SceneNode], device_id: str, file_name: str, limit_mimetypes: bool, file_type: str = "mesh", **kwargs) -> None:
+        """Writes the specified node to the output device.
+        
+        The output device to write with will be selected based on the device_id.
+        A file format is chosen from the list of available file formats by the
+        output device.
+        
+        :param nodes: The scene nodes that must be written to the device.
+        :param device_id: The handle of the device to write to.
+        :param file_name: A suggestion for the file name to write
+        to. Can be freely ignored if providing a file name makes no sense.
+        :param limit_mimetypes: Limit the possible mimetypes to use for writing to these types.
+        :param file_type: What file handler to get the writer from.
+        """
+
         device = self._device_manager.getOutputDevice(device_id)
         if not device:
             return
@@ -132,8 +147,10 @@ class OutputDeviceManagerProxy(QObject):
             message = Message(str(e), title = catalog.i18nc("@info:title", "Error"))
             message.show()
         except Exception as e:
+            message = Message(str(e), title=catalog.i18nc("@info:title", "Error"))
+            message.show()
             Logger.logException("e", "Unable to write to file %s: %s", file_name, e)
 
 
-def createOutputDeviceManagerProxy(engine: QQmlEngine, script_engine: QJSEngine) -> OutputDeviceManagerProxy:
+def createOutputDeviceManagerProxy(engine: "QQmlEngine", script_engine: "QJSEngine") -> OutputDeviceManagerProxy:
     return OutputDeviceManagerProxy()
