@@ -37,9 +37,10 @@ vertexBufferProperty = "__qtgl2_vertex_buffer"
 indexBufferProperty = "__qtgl2_index_buffer"
 
 
-##  A Renderer implementation using PyQt's OpenGL implementation to render.
 @signalemitter
 class QtRenderer(Renderer):
+    """A Renderer implementation using PyQt's OpenGL implementation to render."""
+
     def __init__(self) -> None:
         super().__init__()
 
@@ -63,25 +64,30 @@ class QtRenderer(Renderer):
 
     initialized = Signal()
 
-    ##  Get an integer multiplier that can be used to correct for screen DPI.
     def getPixelMultiplier(self) -> int:
+        """Get an integer multiplier that can be used to correct for screen DPI."""
+
         # Standard assumption for screen pixel density is 96 DPI. We use that as baseline to get
         # a multiplication factor we can use for screens > 96 DPI.
         return round(UM.Qt.QtApplication.QtApplication.getInstance().primaryScreen().physicalDotsPerInch() / 96.0)
 
-    ##  Get the list of render batches.
     def getBatches(self) -> List[RenderBatch]:
+        """Get the list of render batches."""
+
         return self._batches
 
-    ##  Overridden from Renderer.
-    #
-    #   This makes sure the added render pass has the right size.
     def addRenderPass(self, render_pass: "RenderPass") -> None:
+        """Overridden from Renderer.
+        
+        This makes sure the added render pass has the right size.
+        """
+
         super().addRenderPass(render_pass)
         render_pass.setSize(self._viewport_width, self._viewport_height)
 
-    ##  Set background color used when rendering.
     def setBackgroundColor(self, color: QColor) -> None:
+        """Set background color used when rendering."""
+
         self._background_color = color
 
     def getViewportWidth(self) -> int:
@@ -90,30 +96,36 @@ class QtRenderer(Renderer):
     def getViewportHeight(self) -> int:
         return self._viewport_height
 
-    ##  Set the viewport size.
-    #
-    #   \param width The new width of the viewport.
-    #   \param height The new height of the viewport.
     def setViewportSize(self, width: int, height: int) -> None:
+        """Set the viewport size.
+        
+        :param width: The new width of the viewport.
+        :param height: The new height of the viewport.
+        """
+
         self._viewport_width = width
         self._viewport_height = height
 
         for render_pass in self._render_passes:
             render_pass.setSize(width, height)
 
-    ##  Set the window size.
     def setWindowSize(self, width: int, height: int) -> None:
+        """Set the window size."""
+
         self._window_width = width
         self._window_height = height
 
-    ##  Get the window size.
-    #
-    #   \return A tuple of (window_width, window_height)
     def getWindowSize(self) -> Tuple[int, int]:
+        """Get the window size.
+        
+        :return: A tuple of (window_width, window_height)
+        """
+
         return self._window_width, self._window_height
 
-    ##  Overrides Renderer::beginRendering()
     def beginRendering(self) -> None:
+        """Overrides Renderer::beginRendering()"""
+
         if not self._initialized:
             self._initialize()
 
@@ -122,8 +134,9 @@ class QtRenderer(Renderer):
         self._gl.glClear(self._gl.GL_COLOR_BUFFER_BIT | self._gl.GL_DEPTH_BUFFER_BIT)
         self._gl.glClearColor(0.0, 0.0, 0.0, 0.0)
 
-    ##  Overrides Renderer::queueNode()
     def queueNode(self, node: "SceneNode", **kwargs) -> None:
+        """Overrides Renderer::queueNode()"""
+
         type = kwargs.pop("type", RenderBatch.RenderType.Solid)
         if kwargs.pop("transparent", False):
             type = RenderBatch.RenderType.Transparent
@@ -137,8 +150,9 @@ class QtRenderer(Renderer):
 
         self._batches.append(batch)
 
-    ##  Overrides Renderer::render()
     def render(self) -> None:
+        """Overrides Renderer::render()"""
+
         self._batches.sort()
 
         for render_pass in self.getRenderPasses():
@@ -146,22 +160,27 @@ class QtRenderer(Renderer):
             self._gl.glViewport(0, 0, width, height)
             render_pass.render()
 
-    ##  Sometimes not an *entire* new render is required (QML is updated, but the scene did not).
-    #   In that case we ask the composite pass (which must be the last render pass) to render (instead of re-rendering
-    #   all the passes & the views.
     def reRenderLast(self):
+        """Sometimes not an *entire* new render is required (QML is updated, but the scene did not).
+        In that case we ask the composite pass (which must be the last render pass) to render (instead of re-rendering
+        all the passes & the views.
+        """
+
         self.beginRendering() # First ensure that the viewport is set correctly.
         self.getRenderPasses()[-1].render()
 
-    ##  Overrides Renderer::endRendering()
     def endRendering(self) -> None:
+        """Overrides Renderer::endRendering()"""
+
         self._batches.clear()
 
-    ##  Render a full screen quad (rectangle).
-    #
-    #   The function is used to draw render results on.
-    #   \param shader The shader to use when rendering.
     def renderFullScreenQuad(self, shader: "ShaderProgram") -> None:
+        """Render a full screen quad (rectangle).
+        
+        The function is used to draw render results on.
+        :param shader: The shader to use when rendering.
+        """
+
         self._gl.glDisable(self._gl.GL_DEPTH_TEST)
         self._gl.glDisable(self._gl.GL_BLEND)
 
