@@ -22,11 +22,13 @@ from UM.Platform import Platform
 i18n_catalog = i18nCatalog("uranium")
 
 
-##  Container object for the scene graph
-#
-#   The main purpose of this class is to provide the root SceneNode.
 @signalemitter
 class Scene:
+    """Container object for the scene graph
+    
+    The main purpose of this class is to provide the root SceneNode.
+    """
+
     def __init__(self) -> None:
         super().__init__()
 
@@ -67,12 +69,14 @@ class Scene:
     def getSceneLock(self) -> threading.Lock:
         return self._lock
 
-    ##  Get the root node of the scene.
     def getRoot(self) -> "SceneNode":
+        """Get the root node of the scene."""
+
         return self._root
 
-    ##  Change the root node of the scene
     def setRoot(self, node: "SceneNode") -> None:
+        """Change the root node of the scene"""
+
         if self._root != node:
             if not self._ignore_scene_changes:
                 self._disconnectSignalsRoot()
@@ -83,8 +87,9 @@ class Scene:
 
     rootChanged = Signal()
 
-    ##  Get the camera that should be used for rendering.
     def getActiveCamera(self) -> Optional[Camera]:
+        """Get the camera that should be used for rendering."""
+
         return self._active_camera
 
     def getAllCameras(self) -> List[Camera]:
@@ -94,9 +99,12 @@ class Scene:
                 cameras.append(node)
         return cameras
 
-    ##  Set the camera that should be used for rendering.
-    #   \param name The name of the camera to use.
     def setActiveCamera(self, name: str) -> None:
+        """Set the camera that should be used for rendering.
+
+        :param name: The name of the camera to use.
+        """
+
         camera = self.findCamera(name)
         if camera and camera != self._active_camera:
             if self._active_camera:
@@ -106,16 +114,20 @@ class Scene:
         else:
             Logger.log("w", "Couldn't find camera with name [%s] to activate!" % name)
 
-    ##  Signal that is emitted whenever something in the scene changes.
-    #   \param object The object that triggered the change.
     sceneChanged = Signal()
+    """Signal that is emitted whenever something in the scene changes.
+    
+    :param object: The object that triggered the change.
+    """
 
-    ##  Find an object by id.
-    #
-    #   \param object_id The id of the object to search for, as returned by the python id() method.
-    #
-    #   \return The object if found, or None if not.
     def findObject(self, object_id: int) -> Optional["SceneNode"]:
+        """Find an object by id.
+        
+        :param object_id: The id of the object to search for, as returned by the python id() method.
+        
+        :return: The object if found, or None if not.
+        """
+
         for node in BreadthFirstIterator(self._root):
             if id(node) == object_id:
                 return node
@@ -127,22 +139,29 @@ class Scene:
                 return node
         return None
 
-    ##  Add a file to be watched for changes.
-    #   \param file_path The path to the file that must be watched.
     def addWatchedFile(self, file_path: str) -> None:
+        """Add a file to be watched for changes.
+
+        :param file_path: The path to the file that must be watched.
+        """
+
         # The QT 5.10.0 issue, only on Windows. Cura crashes after loading a stl file from USB/sd-card/Cloud-based drive
         if not Platform.isWindows():
             self._file_watcher.addPath(file_path)
 
-    ##  Remove a file so that it will no longer be watched for changes.
-    #   \param file_path The path to the file that must no longer be watched.
     def removeWatchedFile(self, file_path: str) -> None:
+        """Remove a file so that it will no longer be watched for changes.
+
+        :param file_path: The path to the file that must no longer be watched.
+        """
+
         # The QT 5.10.0 issue, only on Windows. Cura crashes after loading a stl file from USB/sd-card/Cloud-based drive
         if not Platform.isWindows():
             self._file_watcher.removePath(file_path)
 
-    ##  Triggered whenever a file is changed that we currently have loaded.
     def _onFileChanged(self, file_path: str) -> None:
+        """Triggered whenever a file is changed that we currently have loaded."""
+
         if not os.path.isfile(file_path) or os.path.getsize(file_path) == 0:  # File doesn't exist any more, or it is empty
             return
 
@@ -162,11 +181,14 @@ class Scene:
             self._reload_message.actionTriggered.connect(self._reload_callback)
             self._reload_message.show()
 
-    ##  Reloads a list of nodes after the user pressed the "Reload" button.
-    #   \param nodes The list of nodes that needs to be reloaded.
-    #   \param message The message that triggered the action to reload them.
-    #   \param action The button that triggered the action to reload them.
     def _reloadNodes(self, nodes: List["SceneNode"], message: str, action: str) -> None:
+        """Reloads a list of nodes after the user pressed the "Reload" button.
+
+        :param nodes: The list of nodes that needs to be reloaded.
+        :param message: The message that triggered the action to reload them.
+        :param action: The button that triggered the action to reload them.
+        """
+
         if action != "reload":
             return
         if self._reload_message is not None:
@@ -183,10 +205,12 @@ class Scene:
                 job.finished.connect(reload_finished_callback)
                 job.start()
 
-    ##  Triggered when reloading has finished.
-    #
-    #   This then puts the resulting mesh data in the node.
     def _reloadJobFinished(self, replaced_node: SceneNode, job: ReadMeshJob) -> None:
+        """Triggered when reloading has finished.
+        
+        This then puts the resulting mesh data in the node.
+        """
+
         for node in job.getResult():
             mesh_data = node.getMeshData()
             if mesh_data:
