@@ -2,41 +2,47 @@
 # Uranium is released under the terms of the LGPLv3 or higher.
 
 from copy import deepcopy
-import numpy
 from typing import Any, Dict, List, Optional, cast
 
-from UM.Math.Matrix import Matrix
-from UM.Math.Vector import Vector
-from UM.Math.Quaternion import Quaternion
-from UM.Math.AxisAlignedBox import AxisAlignedBox
-from UM.Mesh.MeshData import MeshData
+import numpy
 
-from UM.Signal import Signal, signalemitter
-from UM.Mesh.MeshBuilder import MeshBuilder
 from UM.Logger import Logger
-
+from UM.Math.AxisAlignedBox import AxisAlignedBox
+from UM.Math.Matrix import Matrix
+from UM.Math.Quaternion import Quaternion
+from UM.Math.Vector import Vector
+from UM.Mesh.MeshBuilder import MeshBuilder
+from UM.Mesh.MeshData import MeshData
 from UM.Scene.SceneNodeDecorator import SceneNodeDecorator
-##  A scene node object.
-#
-#   These objects can hold a mesh and multiple children. Each node has a transformation matrix
-#   that maps it it's parents space to the local space (it's inverse maps local space to parent).
-#
-#   SceneNodes can be "Decorated" by adding SceneNodeDecorator objects.
-#   These decorators can add functionality to scene nodes.
-#   \sa SceneNodeDecorator
-#   \todo Add unit testing
+from UM.Signal import Signal, signalemitter
+
+
 @signalemitter
 class SceneNode:
+    """A scene node object.
+    
+    These objects can hold a mesh and multiple children. Each node has a transformation matrix
+    that maps it it's parents space to the local space (it's inverse maps local space to parent).
+    
+    SceneNodes can be "Decorated" by adding SceneNodeDecorator objects.
+    These decorators can add functionality to scene nodes.
+    :sa SceneNodeDecorator
+    :todo Add unit testing
+    """
+
     class TransformSpace:
         Local = 1 #type: int
         Parent = 2 #type: int
         World = 3 #type: int
 
-    ##  Construct a scene node.
-    #   \param parent The parent of this node (if any). Only a root node should have None as a parent.
-    #   \param visible Is the SceneNode (and thus, all its children) visible?
-    #   \param name Name of the SceneNode.
-    def __init__(self, parent: Optional["SceneNode"] = None, visible: bool = True, name: str = "") -> None:
+    def __init__(self, parent: Optional["SceneNode"] = None, visible: bool = True, name: str = "", node_id: str = "") -> None:
+        """Construct a scene node.
+
+        :param parent: The parent of this node (if any). Only a root node should have None as a parent.
+        :param visible: Is the SceneNode (and thus, all its children) visible?
+        :param name: Name of the SceneNode.
+        """
+
         super().__init__()  # Call super to make multiple inheritance work.
 
         self._children = []     # type: List[SceneNode]
@@ -76,6 +82,7 @@ class SceneNode:
 
         self._visible = visible  # type: bool
         self._name = name  # type: str
+        self._id = node_id  # type: str
         self._decorators = []  # type: List[SceneNodeDecorator]
 
         # Store custom settings to be compatible with Savitar SceneNode
@@ -102,10 +109,13 @@ class SceneNode:
         self.calculateBoundingBoxMesh()
         return copy
 
-    ##  Set the center position of this node.
-    #   This is used to modify it's mesh data (and it's children) in such a way that they are centered.
-    #   In most cases this means that we use the center of mass as center (which most objects don't use)
     def setCenterPosition(self, center: Vector) -> None:
+        """Set the center position of this node.
+
+        This is used to modify it's mesh data (and it's children) in such a way that they are centered.
+        In most cases this means that we use the center of mass as center (which most objects don't use)
+        """
+
         if self._mesh_data:
             m = Matrix()
             m.setByTranslation(-center)
@@ -113,9 +123,14 @@ class SceneNode:
         for child in self._children:
             child.setCenterPosition(center)
 
-    ##  \brief Get the parent of this node. If the node has no parent, it is the root node.
-    #   \returns SceneNode if it has a parent and None if it's the root node.
     def getParent(self) -> Optional["SceneNode"]:
+        """Get the parent of this node.
+
+        If the node has no parent, it is the root node.
+
+        :returns: SceneNode if it has a parent and None if it's the root node.
+        """
+
         return self._parent
 
     def getMirror(self) -> Vector:
@@ -124,15 +139,19 @@ class SceneNode:
     def setMirror(self, vector) -> None:
         self._mirror = vector
 
-    ##  Get the MeshData of the bounding box
-    #   \returns \type{MeshData} Bounding box mesh.
     def getBoundingBoxMesh(self) -> Optional[MeshData]:
+        """Get the MeshData of the bounding box
+
+        :returns: :type{MeshData} Bounding box mesh.
+        """
+
         if self._bounding_box_mesh is None:
             self.calculateBoundingBoxMesh()
         return self._bounding_box_mesh
 
-    ##  (re)Calculate the bounding box mesh.
     def calculateBoundingBoxMesh(self) -> None:
+        """(re)Calculate the bounding box mesh."""
+
         aabb = self.getBoundingBox()
         if aabb:
             bounding_box_mesh = MeshBuilder()
@@ -177,8 +196,9 @@ class SceneNode:
 
             self._bounding_box_mesh = bounding_box_mesh.build()
 
-    ##  Return if the provided bbox collides with the bbox of this SceneNode
     def collidesWithBbox(self, check_bbox: AxisAlignedBox) -> bool:
+        """Return if the provided bbox collides with the bbox of this SceneNode"""
+
         bbox = self.getBoundingBox()
         if bbox is not None:
             if check_bbox.intersectsBox(bbox) != AxisAlignedBox.IntersectionResult.FullIntersection:
@@ -186,18 +206,23 @@ class SceneNode:
 
         return False
 
-    ##  Handler for the ParentChanged signal
-    #   \param node Node from which this event was triggered.
     def _onParentChanged(self, node: Optional["SceneNode"]) -> None:
+        """Handler for the ParentChanged signal
+        :param node: Node from which this event was triggered.
+        """
+
         for child in self.getChildren():
             child.parentChanged.emit(self)
 
-    ##  Signal for when a \type{SceneNodeDecorator} is added / removed.
     decoratorsChanged = Signal()
+    """Signal for when a :type{SceneNodeDecorator} is added / removed."""
 
-    ##  Add a SceneNodeDecorator to this SceneNode.
-    #   \param \type{SceneNodeDecorator} decorator The decorator to add.
     def addDecorator(self, decorator: SceneNodeDecorator) -> None:
+        """Add a SceneNodeDecorator to this SceneNode.
+
+        :param decorator: The decorator to add.
+        """
+
         if type(decorator) in [type(dec) for dec in self._decorators]:
             Logger.log("w", "Unable to add the same decorator type (%s) to a SceneNode twice.", type(decorator))
             return
@@ -209,29 +234,39 @@ class SceneNode:
         self._decorators.append(decorator)
         self.decoratorsChanged.emit(self)
 
-    ##  Get all SceneNodeDecorators that decorate this SceneNode.
-    #   \return list of all SceneNodeDecorators.
     def getDecorators(self) -> List[SceneNodeDecorator]:
+        """Get all SceneNodeDecorators that decorate this SceneNode.
+
+        :return: list of all SceneNodeDecorators.
+        """
+
         return self._decorators
 
-    ##  Get SceneNodeDecorators by type.
-    #   \param dec_type type of decorator to return.
     def getDecorator(self, dec_type: type) -> Optional[SceneNodeDecorator]:
+        """Get SceneNodeDecorators by type.
+
+        :param dec_type: type of decorator to return.
+        """
+
         for decorator in self._decorators:
             if type(decorator) == dec_type:
                 return decorator
         return None
 
-    ##  Remove all decorators
     def removeDecorators(self):
+        """Remove all decorators"""
+
         for decorator in self._decorators:
             decorator.clear()
         self._decorators = []
         self.decoratorsChanged.emit(self)
 
-    ##  Remove decorator by type.
-    #   \param dec_type type of the decorator to remove.
     def removeDecorator(self, dec_type: type) -> None:
+        """Remove decorator by type.
+
+        :param dec_type: type of the decorator to remove.
+        """
+
         for decorator in self._decorators:
             if type(decorator) == dec_type:
                 decorator.clear()
@@ -239,12 +274,15 @@ class SceneNode:
                 self.decoratorsChanged.emit(self)
                 break
 
-    ##  Call a decoration of this SceneNode.
-    #   SceneNodeDecorators add Decorations, which are callable functions.
-    #   \param function The function to be called.
-    #   \param *args
-    #   \param **kwargs
     def callDecoration(self, function: str, *args, **kwargs) -> Any:
+        """Call a decoration of this SceneNode.
+
+        SceneNodeDecorators add Decorations, which are callable functions.
+        :param function: The function to be called.
+        :param *args
+        :param **kwargs
+        """
+
         for decorator in self._decorators:
             if hasattr(decorator, function):
                 try:
@@ -253,9 +291,11 @@ class SceneNode:
                     Logger.logException("e", "Exception calling decoration %s: %s", str(function), str(e))
                     return None
 
-    ##  Does this SceneNode have a certain Decoration (as defined by a Decorator)
-    #   \param \type{string} function the function to check for.
     def hasDecoration(self, function: str) -> bool:
+        """Does this SceneNode have a certain Decoration (as defined by a Decorator)
+        :param :type{string} function the function to check for.
+        """
+
         for decorator in self._decorators:
             if hasattr(decorator, function):
                 return True
@@ -267,52 +307,77 @@ class SceneNode:
     def setName(self, name: str) -> None:
         self._name = name
 
-    ##  How many nodes is this node removed from the root?
-    #   \return |tupe{int} Steps from root (0 means it -is- the root).
+    def getId(self) -> str:
+        return self._id
+
+    def setId(self, node_id: str) -> None:
+        self._id = node_id
+
     def getDepth(self) -> int:
+        """How many nodes is this node removed from the root?
+
+        :return: Steps from root (0 means it -is- the root).
+        """
+
         if self._parent is None:
             return 0
         return self._parent.getDepth() + 1
 
-    ##  \brief Set the parent of this object
-    #   \param scene_node SceneNode that is the parent of this object.
     def setParent(self, scene_node: Optional["SceneNode"]) -> None:
+        """:brief Set the parent of this object
+
+        :param scene_node: SceneNode that is the parent of this object.
+        """
+
         if self._parent:
             self._parent.removeChild(self)
 
         if scene_node:
             scene_node.addChild(self)
 
-    ##  Emitted whenever the parent changes.
     parentChanged = Signal()
+    """Emitted whenever the parent changes."""
 
-    ##  \brief Get the visibility of this node. The parents visibility overrides the visibility.
-    #   TODO: Let renderer actually use the visibility to decide whether to render or not.
     def isVisible(self) -> bool:
+        """Get the visibility of this node.
+        The parents visibility overrides the visibility.
+        TODO: Let renderer actually use the visibility to decide whether to render or not.
+        """
+
         if self._parent is not None and self._visible:
             return self._parent.isVisible()
         else:
             return self._visible
 
-    ##  Set the visibility of this SceneNode.
     def setVisible(self, visible: bool) -> None:
+        """Set the visibility of this SceneNode."""
+
         self._visible = visible
 
-    ##  \brief Get the (original) mesh data from the scene node/object.
-    #   \returns MeshData
     def getMeshData(self) -> Optional[MeshData]:
+        """Get the (original) mesh data from the scene node/object.
+
+        :returns: MeshData
+        """
+
         return self._mesh_data
 
-    ##  \brief Get the transformed mesh data from the scene node/object, based on the transformation of scene nodes wrt root.
-    #          If this node is a group, it will recursively concatenate all child nodes/objects.
-    #   \returns MeshData
     def getMeshDataTransformed(self) -> Optional[MeshData]:
+        """Get the transformed mesh data from the scene node/object, based on the transformation of scene nodes wrt root.
+
+        If this node is a group, it will recursively concatenate all child nodes/objects.
+        :returns: MeshData
+        """
+
         return MeshData(vertices = self.getMeshDataTransformedVertices(), normals = self.getMeshDataTransformedNormals())
 
-    ##  \brief Get the transformed vertices from this scene node/object, based on the transformation of scene nodes wrt root.
-    #          If this node is a group, it will recursively concatenate all child nodes/objects.
-    #   \return numpy.ndarray
     def getMeshDataTransformedVertices(self) -> numpy.ndarray:
+        """Get the transformed vertices from this scene node/object, based on the transformation of scene nodes wrt root.
+
+        If this node is a group, it will recursively concatenate all child nodes/objects.
+        :return: numpy.ndarray
+        """
+
         transformed_vertices = None
         if self.callDecoration("isGroup"):
             for child in self._children:
@@ -326,10 +391,13 @@ class SceneNode:
                 transformed_vertices = self._mesh_data.getTransformed(self.getWorldTransformation()).getVertices()
         return transformed_vertices
 
-    ##  \brief Get the transformed normals from this scene node/object, based on the transformation of scene nodes wrt root.
-    #          If this node is a group, it will recursively concatenate all child nodes/objects.
-    #   \return numpy.ndarray
     def getMeshDataTransformedNormals(self) -> numpy.ndarray:
+        """Get the transformed normals from this scene node/object, based on the transformation of scene nodes wrt root.
+
+        If this node is a group, it will recursively concatenate all child nodes/objects.
+        :return: numpy.ndarray
+        """
+
         transformed_normals = None
         if self.callDecoration("isGroup"):
             for child in self._children:
@@ -343,22 +411,28 @@ class SceneNode:
                 transformed_normals = self._mesh_data.getTransformed(self.getWorldTransformation()).getNormals()
         return transformed_normals
 
-    ##  \brief Set the mesh of this node/object
-    #   \param mesh_data MeshData object
     def setMeshData(self, mesh_data: Optional[MeshData]) -> None:
+        """Set the mesh of this node/object
+
+        :param mesh_data: MeshData object
+        """
+
         self._mesh_data = mesh_data
         self._resetAABB()
         self.meshDataChanged.emit(self)
 
-    ##  Emitted whenever the attached mesh data object changes.
     meshDataChanged = Signal()
+    """Emitted whenever the attached mesh data object changes."""
 
     def _onMeshDataChanged(self) -> None:
         self.meshDataChanged.emit(self)
 
-    ##  \brief Add a child to this node and set it's parent as this node.
-    #   \params scene_node SceneNode to add.
     def addChild(self, scene_node: "SceneNode") -> None:
+        """Add a child to this node and set it's parent as this node.
+
+        :params scene_node SceneNode to add.
+        """
+
         if scene_node in self._children:
             return
 
@@ -375,9 +449,12 @@ class SceneNode:
             scene_node._transformChanged()
             scene_node.parentChanged.emit(self)
 
-    ##  \brief remove a single child
-    #   \param child Scene node that needs to be removed.
     def removeChild(self, child: "SceneNode") -> None:
+        """remove a single child
+
+        :param child: Scene node that needs to be removed.
+        """
+
         if child not in self._children:
             return
 
@@ -393,46 +470,61 @@ class SceneNode:
         self._resetAABB()
         self.childrenChanged.emit(self)
 
-    ##  \brief Removes all children and its children's children.
     def removeAllChildren(self) -> None:
+        """Removes all children and its children's children."""
+
         for child in self._children:
             child.removeAllChildren()
             self.removeChild(child)
 
         self.childrenChanged.emit(self)
 
-    ##  \brief Get the list of direct children
-    #   \returns List of children
     def getChildren(self) -> List["SceneNode"]:
+        """Get the list of direct children
+
+        :returns: List of children
+        """
+
         return self._children
 
     def hasChildren(self) -> bool:
         return True if self._children else False
 
-    ##  \brief Get list of all children (including it's children children children etc.)
-    #   \returns list ALl children in this 'tree'
     def getAllChildren(self) -> List["SceneNode"]:
+        """Get list of all children (including it's children children children etc.)
+
+        :returns: list ALl children in this 'tree'
+        """
+
         children = []
         children.extend(self._children)
         for child in self._children:
             children.extend(child.getAllChildren())
         return children
 
-    ##  \brief Emitted whenever the list of children of this object or any child object changes.
-    #   \param object The object that triggered the change.
     childrenChanged = Signal()
+    """Emitted whenever the list of children of this object or any child object changes.
+    
+    :param object: The object that triggered the change.
+    """
 
-    ##  \brief Computes and returns the transformation from world to local space.
-    #   \returns 4x4 transformation matrix
     def getWorldTransformation(self) -> Matrix:
+        """Computes and returns the transformation from world to local space.
+
+        :returns: 4x4 transformation matrix
+        """
+
         if self._world_transformation is None:
             self._updateWorldTransformation()
 
         return self._world_transformation.copy()
 
-    ##  \brief Returns the local transformation with respect to its parent. (from parent to local)
-    #   \retuns transformation 4x4 (homogenous) matrix
     def getLocalTransformation(self) -> Matrix:
+        """Returns the local transformation with respect to its parent. (from parent to local)
+
+        :retuns transformation 4x4 (homogenous) matrix
+        """
+
         if self._transformation is None:
             self._updateLocalTransformation()
 
@@ -442,18 +534,21 @@ class SceneNode:
         self._transformation = transformation.copy() # Make a copy to ensure we never change the given transformation
         self._transformChanged()
 
-    ##  Get the local orientation value.
     def getOrientation(self) -> Quaternion:
+        """Get the local orientation value."""
+
         return deepcopy(self._orientation)
 
     def getWorldOrientation(self) -> Quaternion:
         return deepcopy(self._derived_orientation)
 
-    ##  \brief Rotate the scene object (and thus its children) by given amount
-    #
-    #   \param rotation \type{Quaternion} A quaternion indicating the amount of rotation.
-    #   \param transform_space The space relative to which to rotate. Can be any one of the constants in SceneNode::TransformSpace.
     def rotate(self, rotation: Quaternion, transform_space: int = TransformSpace.Local) -> None:
+        """Rotate the scene object (and thus its children) by given amount
+        
+        :param rotation: :type{Quaternion} A quaternion indicating the amount of rotation.
+        :param transform_space: The space relative to which to rotate. Can be any one of the constants in SceneNode::TransformSpace.
+        """
+
         if not self._enabled:
             return
 
@@ -469,11 +564,13 @@ class SceneNode:
 
         self._transformChanged()
 
-    ##  Set the local orientation of this scene node.
-    #
-    #   \param orientation \type{Quaternion} The new orientation of this scene node.
-    #   \param transform_space The space relative to which to rotate. Can be Local or World from SceneNode::TransformSpace.
     def setOrientation(self, orientation: Quaternion, transform_space: int = TransformSpace.Local) -> None:
+        """Set the local orientation of this scene node.
+        
+        :param orientation: :type{Quaternion} The new orientation of this scene node.
+        :param transform_space: The space relative to which to rotate. Can be Local or World from SceneNode::TransformSpace.
+        """
+
         if not self._enabled or orientation == self._orientation:
             return
 
@@ -491,18 +588,21 @@ class SceneNode:
         self._transformation = new_transform_matrix
         self._transformChanged()
 
-    ##  Get the local scaling value.
     def getScale(self) -> Vector:
+        """Get the local scaling value."""
+
         return self._scale
 
     def getWorldScale(self) -> Vector:
         return self._derived_scale
 
-    ##  Scale the scene object (and thus its children) by given amount
-    #
-    #   \param scale \type{Vector} A Vector with three scale values
-    #   \param transform_space The space relative to which to scale. Can be any one of the constants in SceneNode::TransformSpace.
     def scale(self, scale: Vector, transform_space: int = TransformSpace.Local) -> None:
+        """Scale the scene object (and thus its children) by given amount
+        
+        :param scale: :type{Vector} A Vector with three scale values
+        :param transform_space: The space relative to which to scale. Can be any one of the constants in SceneNode::TransformSpace.
+        """
+
         if not self._enabled:
             return
 
@@ -519,11 +619,13 @@ class SceneNode:
 
         self._transformChanged()
 
-    ##  Set the local scale value.
-    #
-    #   \param scale \type{Vector} The new scale value of the scene node.
-    #   \param transform_space The space relative to which to rotate. Can be Local or World from SceneNode::TransformSpace.
     def setScale(self, scale: Vector, transform_space: int = TransformSpace.Local) -> None:
+        """Set the local scale value.
+        
+        :param scale: :type{Vector} The new scale value of the scene node.
+        :param transform_space: The space relative to which to rotate. Can be Local or World from SceneNode::TransformSpace.
+        """
+
         if not self._enabled or scale == self._scale:
             return
         if transform_space == SceneNode.TransformSpace.Local:
@@ -535,19 +637,23 @@ class SceneNode:
 
             self.scale(scale / self._scale, SceneNode.TransformSpace.World)
 
-    ##  Get the local position.
     def getPosition(self) -> Vector:
+        """Get the local position."""
+
         return self._position
 
-    ##  Get the position of this scene node relative to the world.
     def getWorldPosition(self) -> Vector:
+        """Get the position of this scene node relative to the world."""
+
         return self._derived_position
 
-    ##  Translate the scene object (and thus its children) by given amount.
-    #
-    #   \param translation \type{Vector} The amount to translate by.
-    #   \param transform_space The space relative to which to translate. Can be any one of the constants in SceneNode::TransformSpace.
     def translate(self, translation: Vector, transform_space: int = TransformSpace.Local) -> None:
+        """Translate the scene object (and thus its children) by given amount.
+        
+        :param translation: :type{Vector} The amount to translate by.
+        :param transform_space: The space relative to which to translate. Can be any one of the constants in SceneNode::TransformSpace.
+        """
+
         if not self._enabled:
             return
         translation_matrix = Matrix()
@@ -563,11 +669,13 @@ class SceneNode:
             self._transformation.multiply(world_transformation)
         self._transformChanged()
 
-    ##  Set the local position value.
-    #
-    #   \param position The new position value of the SceneNode.
-    #   \param transform_space The space relative to which to rotate. Can be Local or World from SceneNode::TransformSpace.
     def setPosition(self, position: Vector, transform_space: int = TransformSpace.Local) -> None:
+        """Set the local position value.
+        
+        :param position: The new position value of the SceneNode.
+        :param transform_space: The space relative to which to rotate. Can be Local or World from SceneNode::TransformSpace.
+        """
+
         if not self._enabled or position == self._position:
             return
         if transform_space == SceneNode.TransformSpace.Local:
@@ -577,15 +685,18 @@ class SceneNode:
                 return
             self.translate(position - self._derived_position, SceneNode.TransformSpace.World)
 
-    ##  Signal. Emitted whenever the transformation of this object or any child object changes.
-    #   \param object The object that caused the change.
     transformationChanged = Signal()
+    """Signal. Emitted whenever the transformation of this object or any child object changes.
+    :param object: The object that caused the change.
+    """
 
-    ##  Rotate this scene node in such a way that it is looking at target.
-    #
-    #   \param target \type{Vector} The target to look at.
-    #   \param up \type{Vector} The vector to consider up. Defaults to Vector.Unit_Y, i.e. (0, 1, 0).
     def lookAt(self, target: Vector, up: Vector = Vector.Unit_Y) -> None:
+        """Rotate this scene node in such a way that it is looking at target.
+        
+        :param target: :type{Vector} The target to look at.
+        :param up: :type{Vector} The vector to consider up. Defaults to Vector.Unit_Y, i.e. (0, 1, 0).
+        """
+
         if not self._enabled:
             return
 
@@ -604,54 +715,67 @@ class SceneNode:
 
         self.setOrientation(Quaternion.fromMatrix(m))
 
-    ##  Can be overridden by child nodes if they need to perform special rendering.
-    #   If you need to handle rendering in a special way, for example for tool handles,
-    #   you can override this method and render the node. Return True to prevent the
-    #   view from rendering any attached mesh data.
-    #
-    #   \param renderer The renderer object to use for rendering.
-    #
-    #   \return False if the view should render this node, True if we handle our own rendering.
     def render(self, renderer) -> bool:
+        """Can be overridden by child nodes if they need to perform special rendering.
+        If you need to handle rendering in a special way, for example for tool handles,
+        you can override this method and render the node. Return True to prevent the
+        view from rendering any attached mesh data.
+        
+        :param renderer: The renderer object to use for rendering.
+        
+        :return: False if the view should render this node, True if we handle our own rendering.
+        """
+
         return False
 
-    ##  Get whether this SceneNode is enabled, that is, it can be modified in any way.
     def isEnabled(self) -> bool:
+        """Get whether this SceneNode is enabled, that is, it can be modified in any way."""
+
         if self._parent is not None and self._enabled:
             return self._parent.isEnabled()
         else:
             return self._enabled
 
-    ##  Set whether this SceneNode is enabled.
-    #   \param enable True if this object should be enabled, False if not.
-    #   \sa isEnabled
     def setEnabled(self, enable: bool) -> None:
+        """Set whether this SceneNode is enabled.
+
+        :param enable: True if this object should be enabled, False if not.
+        :sa isEnabled
+        """
+
         self._enabled = enable
 
-    ##  Get whether this SceneNode can be selected.
-    #
-    #   \note This will return false if isEnabled() returns false.
     def isSelectable(self) -> bool:
+        """Get whether this SceneNode can be selected.
+        
+        :note This will return false if isEnabled() returns false.
+        """
+
         return self._enabled and self._selectable
 
-    ##  Set whether this SceneNode can be selected.
-    #
-    #   \param select True if this SceneNode should be selectable, False if not.
     def setSelectable(self, select: bool) -> None:
+        """Set whether this SceneNode can be selected.
+        
+        :param select: True if this SceneNode should be selectable, False if not.
+        """
+
         self._selectable = select
 
-    ##  Get the bounding box of this node and its children.
     def getBoundingBox(self) -> Optional[AxisAlignedBox]:
+        """Get the bounding box of this node and its children."""
+
         if not self._calculate_aabb:
             return None
         if self._aabb is None:
             self._calculateAABB()
         return self._aabb
 
-    ##  Set whether or not to calculate the bounding box for this node.
-    #
-    #   \param calculate True if the bounding box should be calculated, False if not.
     def setCalculateBoundingBox(self, calculate: bool) -> None:
+        """Set whether or not to calculate the bounding box for this node.
+        
+        :param calculate: True if the bounding box should be calculated, False if not.
+        """
+
         self._calculate_aabb = calculate
 
     boundingBoxChanged = Signal()
@@ -671,7 +795,6 @@ class SceneNode:
         if self._mesh_data:
             self._mesh_data.invertNormals()
 
-    ##  private:
     def _transformChanged(self) -> None:
         self._updateTransformation()
         self._resetAABB()
@@ -721,7 +844,8 @@ class SceneNode:
                 aabb = aabb + child.getBoundingBox()
         self._aabb = aabb
 
-    ##  String output for debugging.
     def __str__(self) -> str:
+        """String output for debugging."""
+
         name = self._name if self._name != "" else hex(id(self))
         return "<" + self.__class__.__qualname__ + " object: '" + name + "'>"
\ No newline at end of file
