@@ -7,11 +7,13 @@ if TYPE_CHECKING:
     from UM.Scene.SceneNode import SceneNode
 
 
-##      The point of a SceneNodeDecorator is that it can be added to a SceneNode, where it then provides decorations
-#       Decorations are functions of a SceneNodeDecorator that can be called (except for functions already defined
-#       in SceneNodeDecorator).
-#       \sa SceneNode
 class SceneNodeDecorator:
+    """The point of a SceneNodeDecorator is that it can be added to a SceneNode, where it then provides decorations
+    Decorations are functions of a SceneNodeDecorator that can be called (except for functions already defined
+    in SceneNodeDecorator).
+    :sa SceneNode
+    """
+
     def __init__(self, node: Optional["SceneNode"] = None) -> None:
         super().__init__()
         self._node = node  # type: Optional["SceneNode"]
@@ -22,8 +24,9 @@ class SceneNodeDecorator:
     def getNode(self) -> Optional["SceneNode"]:
         return self._node
 
-    ##  Clear all data associated with this decorator. This will be called before the decorator is removed
     def clear(self) -> None:
+        """Clear all data associated with this decorator. This will be called before the decorator is removed"""
+
         pass
 
     def __deepcopy__(self, memo: Dict[int, object]) -> "SceneNodeDecorator":
