@@ -17,11 +17,13 @@ from UM.View.GL.OpenGL import OpenGL
 from UM.View.RenderBatch import RenderBatch
 
 
-##    A tool handle is a object in the scene that gives queues for what the tool it is
-#     'paired' with can do. ToolHandles are, for example, used for translation, rotation & scale handles.
-#     They can also be used as actual objects to interact with (in the case of translation,
-#     pressing one arrow of the toolhandle locks the translation in that direction)
 class ToolHandle(SceneNode.SceneNode):
+    """A tool handle is a object in the scene that gives queues for what the tool it is
+    'paired' with can do. ToolHandles are, for example, used for translation, rotation & scale handles.
+    They can also be used as actual objects to interact with (in the case of translation,
+    pressing one arrow of the toolhandle locks the translation in that direction)
+    """
+
     NoAxis = 1
     XAxis = 2
     YAxis = 3
@@ -88,7 +90,10 @@ class ToolHandle(SceneNode.SceneNode):
         self._selection_mesh = mesh
         self.meshDataChanged.emit(self)
 
-    def render(self, renderer):
+    def render(self, renderer) -> bool:
+        if not self._enabled:
+            return True
+
         if not self._shader:
             self._shader = OpenGL.getInstance().createShaderProgram(Resources.getPath(Resources.Shaders, "toolhandle.shader"))
 
