@@ -67,7 +67,6 @@ class SignalQueue:
     def getMainThread(self):
         pass
 
-###########################################################################
 # Integration with the Flame Profiler.
 
 
@@ -91,48 +90,50 @@ def profileEmit(func):
         return func
 
 
-###########################################################################
-
-##  Simple implementation of signals and slots.
-#
-#   Signals and slots can be used as a light weight event system. A class can
-#   define signals that other classes can connect functions or methods to, called slots.
-#   Whenever the signal is called, it will proceed to call the connected slots.
-#
-#   To create a signal, create an instance variable of type Signal. Other objects can then
-#   use that variable's `connect()` method to connect methods, callable objects or signals
-#   to the signal. To emit the signal, call `emit()` on the signal. Arguments can be passed
-#   along to the signal, but slots will be required to handle them. When connecting signals
-#   to other signals, the connected signal will be emitted whenever the signal is emitted.
-#
-#   Signal-slot connections are weak references and as such will not prevent objects
-#   from being destroyed. In addition, all slots will be implicitly disconnected when
-#   the signal is destroyed.
-#
-#   \warning It is imperative that the signals are created as instance variables, otherwise
-#   emitting signals will get confused. To help with this, see the SignalEmitter class.
-#
-#   Loosely based on http://code.activestate.com/recipes/577980-improved-signalsslots-implementation-in-python/ #pylint: disable=wrong-spelling-in-comment
-#   \sa SignalEmitter
 class Signal:
-    ##  Signal types.
-    #   These indicate the type of a signal, that is, how the signal handles calling the connected
-    #   slots.
-    #   - Direct connections immediately call the connected slots from the thread that called emit().
-    #   - Auto connections will push the call onto the event loop if the current thread is
-    #     not the main thread, but make a direct call if it is.
-    #   - Queued connections will always push
-    #     the call on to the event loop.
+    """Simple implementation of signals and slots.
+    
+    Signals and slots can be used as a light weight event system. A class can
+    define signals that other classes can connect functions or methods to, called slots.
+    Whenever the signal is called, it will proceed to call the connected slots.
+    
+    To create a signal, create an instance variable of type Signal. Other objects can then
+    use that variable's `connect()` method to connect methods, callable objects or signals
+    to the signal. To emit the signal, call `emit()` on the signal. Arguments can be passed
+    along to the signal, but slots will be required to handle them. When connecting signals
+    to other signals, the connected signal will be emitted whenever the signal is emitted.
+    
+    Signal-slot connections are weak references and as such will not prevent objects
+    from being destroyed. In addition, all slots will be implicitly disconnected when
+    the signal is destroyed.
+    
+    **WARNING** It is imperative that the signals are created as instance variables, otherwise
+    emitting signals will get confused. To help with this, see the SignalEmitter class.
+    
+    Loosely based on http://code.activestate.com/recipes/577980-improved-signalsslots-implementation-in-python/    pylint: disable=wrong-spelling-in-comment
+    :sa SignalEmitter
+    """
+
     Direct = 1
+    """Signal types.
+    These indicate the type of a signal, that is, how the signal handles calling the connected
+    slots.
+    
+    - Direct connections immediately call the connected slots from the thread that called emit().
+    - Auto connections will push the call onto the event loop if the current thread is
+      not the main thread, but make a direct call if it is.
+    - Queued connections will always push
+      the call on to the event loop.
+    """
     Auto = 2
     Queued = 3
 
-    ##  Initialize the instance.
-    #
-    #   \param kwargs Keyword arguments.
-    #                 Possible keywords:
-    #                 - type: The signal type. Defaults to Auto.
     def __init__(self, type: int = Auto) -> None:
+        """Initialize the instance.
+        
+        :param type: The signal type. Defaults to Auto.
+        """
+
         # These collections must be treated as immutable otherwise we lose thread safety.
         self.__functions = WeakImmutableList()      # type: WeakImmutableList[Callable[[], None]]
         self.__methods = WeakImmutablePairList()    # type: WeakImmutablePairList[Any, Callable[[], None]]
@@ -160,26 +161,32 @@ class Signal:
     def getName(self):
         return self.__name
 
-    ##  \exception NotImplementedError
     def __call__(self) -> None:
+        """:exception NotImplementedError:"""
+
         raise NotImplementedError("Call emit() to emit a signal")
 
-    ##  Get type of the signal
-    #   \return \type{int} Direct(1), Auto(2) or Queued(3)
     def getType(self) -> int:
+        """Get type of the signal
+
+        :return: Direct(1), Auto(2) or Queued(3)
+        """
+
         return self.__type
 
-    ##  Emit the signal which indirectly calls all of the connected slots.
-    #
-    #   \param args The positional arguments to pass along.
-    #   \param kwargs The keyword arguments to pass along.
-    #
-    #   \note If the Signal type is Queued and this is not called from the application thread
-    #   the call will be posted as an event to the application main thread, which means the
-    #   function will be called on the next application event loop tick.
     @call_if_enabled(_traceEmit, _isTraceEnabled())
     @profileEmit
     def emit(self, *args: Any, **kwargs: Any) -> None:
+        """Emit the signal which indirectly calls all of the connected slots.
+        
+        :param args: The positional arguments to pass along.
+        :param kwargs: The keyword arguments to pass along.
+        
+        :note If the Signal type is Queued and this is not called from the application thread
+        the call will be posted as an event to the application main thread, which means the
+        function will be called on the next application event loop tick.
+        """
+
         # Check to see if we need to postpone emits
         if self._postpone_emit:
             if threading.current_thread() != self._postpone_thread:
@@ -211,10 +218,13 @@ class Signal:
 
         self.__performEmit(*args, **kwargs)
 
-    ##  Connect to this signal.
-    #   \param connector The signal or slot (function) to connect.
     @call_if_enabled(_traceConnect, _isTraceEnabled())
     def connect(self, connector: Union["Signal", Callable[[], None]]) -> None:
+        """Connect to this signal.
+
+        :param connector: The signal or slot (function) to connect.
+        """
+
         if self._postpone_emit:
             Logger.log("w", "Tried to connect to signal %s that is currently being postponed, this is not possible", self.__name)
             return
@@ -235,10 +245,13 @@ class Signal:
 
                 self.__functions = self.__functions.append(connector)
 
-    ##  Disconnect from this signal.
-    #   \param connector The signal or slot (function) to disconnect.
     @call_if_enabled(_traceDisconnect, _isTraceEnabled())
     def disconnect(self, connector):
+        """Disconnect from this signal.
+
+        :param connector: The signal or slot (function) to disconnect.
+        """
+
         if self._postpone_emit:
             Logger.log("w", "Tried to disconnect from signal %s that is currently being postponed, this is not possible", self.__name)
             return
@@ -251,8 +264,9 @@ class Signal:
             else:
                 self.__functions = self.__functions.remove(connector)
 
-    ##  Disconnect all connected slots.
     def disconnectAll(self):
+        """Disconnect all connected slots."""
+
         if self._postpone_emit:
             Logger.log("w", "Tried to disconnect from signal %s that is currently being postponed, this is not possible", self.__name)
             return
@@ -262,18 +276,22 @@ class Signal:
             self.__methods = WeakImmutablePairList()    # type: "WeakImmutablePairList"
             self.__signals = WeakImmutableList()        # type: "WeakImmutableList"
 
-    ##  To support Pickle
-    #
-    #   Since Weak containers cannot be serialized by Pickle we just return an empty dict as state.
     def __getstate__(self):
+        """To support Pickle
+        
+        Since Weak containers cannot be serialized by Pickle we just return an empty dict as state.
+        """
+
         return {}
 
-    ##  To properly handle deepcopy in combination with __getstate__
-    #
-    #   Apparently deepcopy uses __getstate__ internally, which is not documented. The reimplementation
-    #   of __getstate__ then breaks deepcopy. On the other hand, if we do not reimplement it like that,
-    #   we break pickle. So instead make sure to also reimplement __deepcopy__.
     def __deepcopy__(self, memo):
+        """To properly handle deepcopy in combination with __getstate__
+        
+        Apparently deepcopy uses __getstate__ internally, which is not documented. The reimplementation
+        of __getstate__ then breaks deepcopy. On the other hand, if we do not reimplement it like that,
+        we break pickle. So instead make sure to also reimplement __deepcopy__.
+        """
+
         # Snapshot these fields
         with self.__lock:
             functions = self.__functions
@@ -286,11 +304,10 @@ class Signal:
         signal.__signals = signals
         return signal
 
-    ##  private:
-
-    #   To avoid circular references when importing Application, this should be
-    #   set by the Application instance.
     _app = None  # type: Application
+    """To avoid circular references when importing Application, this should be
+    set by the Application instance.
+    """
 
     _signalQueue = None  # type: Application
 
@@ -350,22 +367,24 @@ class CompressTechnique(enum.Enum):
     CompressSingle = 1
     CompressPerParameterValue = 2
 
-##  A context manager that allows postponing of signal emissions
-#
-#   This context manager will collect any calls to emit() made for the provided signals
-#   and only emit them after exiting. This ensures more batched processing of signals.
-#
-#   The optional "compress" argument will limit the emit calls to 1. This means that
-#   when a bunch of calls are made to the signal's emit() method, only the last call
-#   will be emitted on exit.
-#
-#   \warning When compress is True, only the **last** call will be emitted. This means
-#   that any other calls will be ignored, _including their arguments_.
-#
-#   \param signals The signals to postpone emits for.
-#   \param compress Whether to enable compression of emits or not.
 @contextlib.contextmanager
 def postponeSignals(*signals, compress: CompressTechnique = CompressTechnique.NoCompression):
+    """A context manager that allows postponing of signal emissions
+    
+    This context manager will collect any calls to emit() made for the provided signals
+    and only emit them after exiting. This ensures more batched processing of signals.
+    
+    The optional "compress" argument will limit the emit calls to 1. This means that
+    when a bunch of calls are made to the signal's emit() method, only the last call
+    will be emitted on exit.
+    
+    **WARNING** When compress is True, only the **last** call will be emitted. This means
+    that any other calls will be ignored, _including their arguments_.
+    
+    :param signals: The signals to postpone emits for.
+    :param compress: Whether to enable compression of emits or not.
+    """
+
     # To allow for nested postpones on the same signals, we should check if signals are not already
     # postponed and only change those that are not yet postponed.
     restore_emit = []
@@ -401,14 +420,16 @@ def postponeSignals(*signals, compress: CompressTechnique = CompressTechnique.No
         signal._compress_postpone = False
 
 
-##  Class decorator that ensures a class has unique instances of signals.
-#
-#   Since signals need to be instance variables, normally you would need to create all
-#   signals in the class" `__init__` method. However, this makes them rather awkward to
-#   document. This decorator instead makes it possible to declare them as class variables,
-#   which makes documenting them near the function they are used possible. This decorator
-#   adjusts the class' __new__ method to create new signal instances for all class signals.
 def signalemitter(cls):
+    """Class decorator that ensures a class has unique instances of signals.
+    
+    Since signals need to be instance variables, normally you would need to create all
+    signals in the class" `__init__` method. However, this makes them rather awkward to
+    document. This decorator instead makes it possible to declare them as class variables,
+    which makes documenting them near the function they are used possible. This decorator
+    adjusts the class' __new__ method to create new signal instances for all class signals.
+    """
+
     # First, check if the base class has any signals defined
     signals = inspect.getmembers(cls, lambda i: isinstance(i, Signal))
     if not signals:
@@ -435,32 +456,38 @@ def signalemitter(cls):
 T = TypeVar('T')
 
 
-##  Minimal implementation of a weak reference list with immutable tendencies.
-#
-#   Strictly speaking this isn't immutable because the garbage collector can modify
-#   it, but no application code can. Also, this class doesn't implement the Python
-#   list API, only the handful of methods we actually need in the code above.
 class WeakImmutableList(Generic[T], Iterable):
+    """Minimal implementation of a weak reference list with immutable tendencies.
+    
+    Strictly speaking this isn't immutable because the garbage collector can modify
+    it, but no application code can. Also, this class doesn't implement the Python
+    list API, only the handful of methods we actually need in the code above.
+    """
+
     def __init__(self) -> None:
         self.__list = []    # type: List[ReferenceType[Optional[T]]]
 
-    ## Append an item and return a new list
-    #
-    #  \param item the item to append
-    #  \return a new list
     def append(self, item: T) -> "WeakImmutableList[T]":
+        """Append an item and return a new list
+        
+        :param item: the item to append
+        :return: a new list
+        """
+
         new_instance = WeakImmutableList()  # type: WeakImmutableList[T]
         new_instance.__list = self.__cleanList()
         new_instance.__list.append(ReferenceType(item))
         return new_instance
 
-    ## Remove an item and return a list
-    #
-    #  Note that unlike the normal Python list.remove() method, this ones
-    #  doesn't throw a ValueError if the item isn't in the list.
-    #  \param item item to remove
-    #  \return a list which does not have the item.
     def remove(self, item: T) -> "WeakImmutableList[T]":
+        """Remove an item and return a list
+        
+        Note that unlike the normal Python list.remove() method, this ones
+        doesn't throw a ValueError if the item isn't in the list.
+        :param item: item to remove
+        :return: a list which does not have the item.
+        """
+
         for item_ref in self.__list:
             if item_ref() is item:
                 new_instance = WeakImmutableList()   # type: WeakImmutableList[T]
@@ -478,11 +505,13 @@ class WeakImmutableList(Generic[T], Iterable):
         return WeakImmutableListIterator(self.__list)
 
 
-## Iterator wrapper which filters out missing values.
-#
-# It dereferences each weak reference object and filters out the objects
-# which have already disappeared via GC.
 class WeakImmutableListIterator(Generic[T], Iterable):
+    """Iterator wrapper which filters out missing values.
+    
+    It dereferences each weak reference object and filters out the objects
+    which have already disappeared via GC.
+    """
+
     def __init__(self, list_):
         self.__it = list_.__iter__()
 
@@ -499,28 +528,33 @@ class WeakImmutableListIterator(Generic[T], Iterable):
 U = TypeVar('U')
 
 
-##  A variation of WeakImmutableList which holds a pair of values using weak refernces.
 class WeakImmutablePairList(Generic[T, U], Iterable):
+    """A variation of WeakImmutableList which holds a pair of values using weak refernces."""
+
     def __init__(self) -> None:
         self.__list = []    # type: List[Tuple[ReferenceType[T],ReferenceType[U]]]
 
-    ## Append an item and return a new list
-    #
-    #  \param item the item to append
-    #  \return a new list
     def append(self, left_item: T, right_item: U) -> "WeakImmutablePairList[T,U]":
+        """Append an item and return a new list
+        
+        :param item: the item to append
+        :return: a new list
+        """
+
         new_instance = WeakImmutablePairList()  # type: WeakImmutablePairList[T,U]
         new_instance.__list = self.__cleanList()
         new_instance.__list.append( (weakref.ref(left_item), weakref.ref(right_item)) )
         return new_instance
 
-    ## Remove an item and return a list
-    #
-    #  Note that unlike the normal Python list.remove() method, this ones
-    #  doesn't throw a ValueError if the item isn't in the list.
-    #  \param item item to remove
-    #  \return a list which does not have the item.
     def remove(self, left_item: T, right_item: U) -> "WeakImmutablePairList[T,U]":
+        """Remove an item and return a list
+        
+        Note that unlike the normal Python list.remove() method, this ones
+        doesn't throw a ValueError if the item isn't in the list.
+        :param item: item to remove
+        :return: a list which does not have the item.
+        """
+
         for pair in self.__list:
             left = pair[0]()
             right = pair[1]()
