@@ -1,10 +1,10 @@
 # Copyright (c) 2020 Ultimaker B.V.
 # Uranium is released under the terms of the LGPLv3 or higher.
-
-from collections import deque
-from threading import RLock
+import json
 import time
 import uuid
+from collections import deque
+from threading import RLock
 from typing import Callable, cast, Dict, Set, Union, Optional, Any
 
 from PyQt5.QtCore import QObject, QUrl, Qt
@@ -13,7 +13,6 @@ from PyQt5.QtNetwork import QNetworkAccessManager, QNetworkRequest, QNetworkRepl
 from UM.Logger import Logger
 from UM.TaskManagement.HttpRequestData import HttpRequestData
 from UM.TaskManagement.HttpRequestScope import HttpRequestScope
-
 from UM.TaskManagement.TaskManager import TaskManager
 
 
@@ -193,6 +192,45 @@ class HttpRequestManager(TaskManager):
                     request.reply.abort()
                     Logger.log("d", "%s aborted", request)
 
+    @staticmethod
+    def readJSON(reply: QNetworkReply) -> Any:
+        """ Read a Json response into a Python object (list, dict, str depending on json type)
+
+        :return: Python object representing the Json or None in case of error
+        """
+        try:
+            return json.loads(HttpRequestManager.readText(reply))
+        except json.decoder.JSONDecodeError:
+            Logger.log("w", "Received invalid JSON: " + str(reply.url()))
+            return None
+
+    @staticmethod
+    def readText(reply: QNetworkReply) -> str:
+        """Decode raw reply bytes as utf-8"""
+        return bytes(reply.readAll()).decode("utf-8")
+
+    @staticmethod
+    def replyIndicatesSuccess(reply: QNetworkReply, error: Optional["QNetworkReply.NetworkError"] = None) -> bool:
+        """Returns whether reply status code indicates success and error is None"""
+        return error is None and 200 <= reply.attribute(QNetworkRequest.HttpStatusCodeAttribute) < 300
+
+    @staticmethod
+    def safeHttpStatus(reply: Optional[QNetworkReply]):
+        """Returns the status code or -1 if there isn't any"""
+        if reply is None:
+            return -1
+
+        return reply.attribute(QNetworkRequest.HttpStatusCodeAttribute) or -1
+
+    @staticmethod
+    def qt_network_error_name(error: QNetworkReply.NetworkError):
+        """String representation of a NetworkError, eg 'ProtocolInvalidOperationError'"""
+
+        for k, v in QNetworkReply.__dict__.items():
+            if v == error:
+                return k
+        return "Unknown Qt Network error"
+
     # This function creates a HttpRequestData with the given data and puts it into the pending request queue.
     # If no request processing call has been scheduled, it will schedule it too.
     # Returns an HttpRequestData instance that represents this request.
@@ -225,7 +263,7 @@ class HttpRequestManager(TaskManager):
                 request.setRawHeader(key.encode("utf-8"), value.encode("utf-8"))
 
         if scope is not None:
-            scope.request_hook(request)
+            scope.requestHook(request)
 
         # Generate a unique request ID
         request_id = uuid.uuid4().hex
@@ -360,8 +398,9 @@ class HttpRequestManager(TaskManager):
         #
         # We do nothing if the request was aborted or and error was detected because an error callback will also
         # be triggered by Qt.
-        if request_data.reply is not None and request_data.reply.error() != QNetworkReply.NoError:
-            if request_data.reply.error() == QNetworkReply.OperationCanceledError:
+        reply = request_data.reply
+        if reply is not None and reply.error() != QNetworkReply.NoError:
+            if reply.error() == QNetworkReply.OperationCanceledError:
                 Logger.log("d", "%s was aborted, do nothing", request_data)
             # stop processing for any kind of error
             return
@@ -383,18 +422,22 @@ class HttpRequestManager(TaskManager):
                 Logger.log("e", "%s not found in the in-progress set", request_data)
             else:
                 # Disconnect callback signals
-                if request_data.reply is not None:
+                if reply is not None:
+                    # Even after the request was successfully finished, an error may still be emitted if
+                    # the network connection is lost seconds later. Bug in Qt? Fixes CURA-7349
+                    reply.error.disconnect()
+
                     if request_data.download_progress_callback is not None:
-                        request_data.reply.downloadProgress.disconnect(request_data.onDownloadProgressCallback)
+                        reply.downloadProgress.disconnect(request_data.onDownloadProgressCallback)
                     if request_data.upload_progress_callback is not None:
-                        request_data.reply.uploadProgress.disconnect(request_data.onUploadProgressCallback)
+                        reply.uploadProgress.disconnect(request_data.onUploadProgressCallback)
 
                 request_data.setDone()
                 self._requests_in_progress.remove(request_data)
 
         # Schedule the callback if there is one
         if request_data.callback is not None:
-            self.callLater(0, request_data.callback, request_data.reply)
+            self.callLater(0, request_data.callback, reply)
 
         # Continue to process the next request
         self._processNextRequestsInQueue()
