@@ -5,17 +5,20 @@ from typing import cast, Union, List
 from UM.Logger import Logger
 
 
-##  Represents a version number, like "3.2.8" and allows comparison of those
-#   numbers.
 class Version:
+    """Represents a version number, like "3.2.8" and allows comparison of those
+    numbers.
+    """
 
-    ##  Constructs the version instance from a string representing the version.
-    #
-    #   The string representation may have dashes or underscores that separate
-    #   the major, minor and revision version numbers. All text is ignored.
-    #
-    #   \param version A string or bytes representing a version number.
     def __init__(self, version: Union[str, bytes, int, "Version", List[Union[int, str, bytes]]]) -> None:
+        """Constructs the version instance from a string representing the version.
+        
+        The string representation may have dashes or underscores that separate
+        the major, minor and revision version numbers. All text is ignored.
+        
+        :param version: A string or bytes representing a version number.
+        """
+
         super().__init__()
 
         if type(version) == bytes:
@@ -57,48 +60,62 @@ class Version:
         except ValueError:
             pass
 
-    ##  Gets the major version number.
-    #
-    #   The major version number is the first number of the version: "3" in the
-    #   version "3.2.8".
     def getMajor(self) -> int:
+        """Gets the major version number.
+        
+        The major version number is the first number of the version: "3" in the
+        version "3.2.8".
+        """
+
         return self._major
 
-    ##  Gets the minor version number.
-    #
-    #   The minor version number is the second number of the version: "2" in the
-    #   version "3.2.8".
     def getMinor(self) -> int:
+        """Gets the minor version number.
+        
+        The minor version number is the second number of the version: "2" in the
+        version "3.2.8".
+        """
+
         return self._minor
 
-    ##  Gets the revision or patch version number.
-    #
-    #   The revision version number is the third number of the version: "8" in
-    #   the version "3.2.8".
     def getRevision(self) -> int:
+        """Gets the revision or patch version number.
+        
+        The revision version number is the third number of the version: "8" in
+        the version "3.2.8".
+        """
+
         return self._revision
 
-    ##  Gets the postfix type.
-    #
-    #   The postfix type is the name of the postfix, e.g. "alpha" in the version "1.2.3-alpha.4"
     def getPostfixType(self) -> str:
+        """Gets the postfix type.
+        
+        The postfix type is the name of the postfix, e.g. "alpha" in the version "1.2.3-alpha.4"
+        """
+
         return self._postfix_type
 
-    ##  Gets the postfix version number.
-    #
-    #   The postfix version is the last number, e.g. "4" in the version "1.2.3-alpha.4"
     def getPostfixVersion(self) -> int:
+        """Gets the postfix version number.
+        
+        The postfix version is the last number, e.g. "4" in the version "1.2.3-alpha.4"
+        """
+
         return self._postfix_version
 
-    ##  Check if a version has a postfix.
     def hasPostFix(self) -> bool:
+        """Check if a version has a postfix."""
+
         return self.getPostfixVersion() > 0 and self._postfix_type != ""
 
-    ##  Indicates whether this version is later than the specified version.
-    #
-    #   Implements the > operator.
-    #   \param other Either another version object or a string representing one.
     def __gt__(self, other: Union["Version", str]) -> bool:
+        """Indicates whether this version is later than the specified version.
+        
+        Implements the > operator.
+
+        :param other: Either another version object or a string representing one.
+        """
+
         if isinstance(other, Version):
             return other.__lt__(self)
         elif isinstance(other, str):
@@ -106,11 +123,14 @@ class Version:
         else:
             return False
 
-    ##  Indicates whether this version is earlier than the specified version.
-    #
-    #   Implements the < operator.
-    #   \param other Either another version object or a string representing one.
     def __lt__(self, other: Union["Version", str]) -> bool:
+        """Indicates whether this version is earlier than the specified version.
+        
+        Implements the < operator.
+
+        :param other: Either another version object or a string representing one.
+        """
+
         if isinstance(other, Version):
             if self._major < other.getMajor():
                 # The major version is lower.
@@ -146,11 +166,14 @@ class Version:
         else:
             return False
 
-    ##  Indicates whether this version is equal to the specified version.
-    #
-    #   Implements the == operator.
-    #   \param other Either another version object or a string representing one.
     def __eq__(self, other: object) -> bool:
+        """Indicates whether this version is equal to the specified version.
+        
+        Implements the == operator.
+
+        :param other: Either another version object or a string representing one.
+        """
+
         if isinstance(other, Version):
             # Direct comparison with same type.
             return self._major == other.getMajor() \
@@ -165,33 +188,42 @@ class Version:
 
         return False
 
-    ##  Indicates whether this version is later or equal to the specified
-    #   version.
-    #
-    #   Implements the >= operator.
-    #   \param other Either another version object or a string representing one.
     def __ge__(self, other: Union["Version", str]) -> bool:
+        """Indicates whether this version is later or equal to the specified
+        version.
+        
+        Implements the >= operator.
+
+        :param other: Either another version object or a string representing one.
+        """
+
         return self.__gt__(other) or self.__eq__(other)
 
-    ##  Indicates whether this version is earlier or equal to the specified
-    #   version.
-    #
-    #   Implements the <= operator.
-    #   \param other Either another version object or a string representing one.
     def __le__(self, other: Union["Version", str]) -> bool:
+        """Indicates whether this version is earlier or equal to the specified
+        version.
+        
+        Implements the <= operator.
+
+        :param other: Either another version object or a string representing one.
+        """
+
         return self.__lt__(other) or self.__eq__(other)
 
-    ##  Returns a string representation containing the major, minor and revision
-    #   number.
-    #
-    #   Such as "3.2.8".
     def __str__(self) -> str:
+        """Returns a string representation containing the major, minor and revision
+        number.
+        
+        Such as "3.2.8".
+        """
+
         if self._postfix_type:
             # If we have a postfix, return a string including that postfix.
             return "%s.%s.%s-%s.%s"\
                    % (self._major, self._minor, self._revision, self._postfix_type, self._postfix_version)
         return "%s.%s.%s" % (self._major, self._minor, self._revision)
 
-    ##  Returns a number reasonably representing the identity of the version.
     def __hash__(self) -> int:
+        """Returns a number reasonably representing the identity of the version."""
+
         return hash(self.__str__())
