@@ -4,31 +4,34 @@
 import os  # For getting the IDs from a filename.
 import pickle  # For caching definitions.
 import re  # To detect back-up files in the ".../old/#/..." folders.
-from typing import Any, Dict, Iterable, Optional, Set, Type
 import urllib.parse  # For interpreting escape characters using unquote_plus.
+from typing import Any, Dict, Iterable, Optional, Set
 
 from UM.Application import Application  # To get the current version for finding the cache directory.
 from UM.ConfigurationErrorMessage import ConfigurationErrorMessage
-from UM.Settings.ContainerRegistry import ContainerRegistry  # To get the resource types for containers.
 from UM.Logger import Logger
 from UM.MimeTypeDatabase import MimeTypeDatabase, MimeType  # To get the type of container we're loading.
+from UM.Platform import Platform
+from UM.Resources import Resources
 from UM.SaveFile import SaveFile
 from UM.Settings.ContainerProvider import ContainerProvider  # The class we're implementing.
+from UM.Settings.ContainerRegistry import ContainerRegistry  # To get the resource types for containers.
 from UM.Settings.DefinitionContainer import DefinitionContainer  # To check if we need to cache this container.
-from UM.Resources import Resources
-from UM.Platform import Platform
 
 MYPY = False
 if MYPY:  # Things to import for type checking only.
     from UM.Settings.Interfaces import ContainerInterface
 
 
-##  Provides containers from the local installation.
 class LocalContainerProvider(ContainerProvider):
-    ##  Creates the local container provider.
-    #
-    #   This creates a cache which translates container IDs to their file names.
+    """Provides containers from the local installation."""
+
     def __init__(self):
+        """Creates the local container provider.
+        
+        This creates a cache which translates container IDs to their file names.
+        """
+
         super().__init__()
 
         self._id_to_path = {}  # type: Dict[str, str] #Translates container IDs to the path to where the file is located
@@ -39,10 +42,12 @@ class LocalContainerProvider(ContainerProvider):
     def getContainerFilePathById(self, container_id: str) -> Optional[str]:
         return self._id_to_path.get(container_id)
 
-    ##  Gets the IDs of all local containers.
-    #
-    #   \return A sequence of all container IDs.
     def getAllIds(self) -> Iterable[str]:
+        """Gets the IDs of all local containers.
+        
+        :return: A sequence of all container IDs.
+        """
+
         if not self._id_to_path:
             self._updatePathCache()
         return self._id_to_path.keys()
@@ -76,8 +81,9 @@ class LocalContainerProvider(ContainerProvider):
         # If we're not requesting the base ID, the sub-container must have been side loaded.
         return ContainerRegistry.getInstance().findContainers(id = container_id)[0]
 
-    ##  Find out where to save a container and save it there
     def saveContainer(self, container: "ContainerInterface") -> None:
+        """Find out where to save a container and save it there"""
+
         try:
             data = container.serialize()
         except NotImplementedError:
@@ -118,12 +124,14 @@ class LocalContainerProvider(ContainerProvider):
         else:
             Logger.log("w", "Dirty container [%s] is not saved because the resource type is unknown in ContainerRegistry", container_type)
 
-    ##  Load the metadata of a specified container.
-    #
-    #   \param container_id The ID of the container to load the metadata of.
-    #   \return The metadata of the specified container, or ``None`` if the
-    #   metadata failed to load.
     def loadMetadata(self, container_id: str) -> Dict[str, Any]:
+        """Load the metadata of a specified container.
+        
+        :param container_id: The ID of the container to load the metadata of.
+        :return: The metadata of the specified container, or `None` if the
+                 metadata failed to load.
+        """
+
         registry = ContainerRegistry.getInstance()
         if container_id in registry.metadata:
             return registry.metadata[container_id]
@@ -158,11 +166,13 @@ class LocalContainerProvider(ContainerProvider):
                 registry.source_provider[metadata["id"]] = self
         return requested_metadata
 
-    ##  Returns whether a container is read-only or not.
-    #
-    #   A container can only be modified if it is stored in the data directory.
-    #   \return Whether the specified container is read-only.
     def isReadOnly(self, container_id: str) -> bool:
+        """Returns whether a container is read-only or not.
+        
+        A container can only be modified if it is stored in the data directory.
+        :return: Whether the specified container is read-only.
+        """
+
         if container_id in self._is_read_only_cache:
             return self._is_read_only_cache[container_id]
         storage_path = os.path.realpath(Resources.getDataStoragePath())
@@ -183,8 +193,9 @@ class LocalContainerProvider(ContainerProvider):
         self._is_read_only_cache[container_id] = result
         return result
 
-    ##  Remove or unregister an id.
     def removeContainer(self, container_id: str) -> None:
+        """Remove or unregister an id."""
+
         if container_id not in self._id_to_path:
             Logger.log("w", "Tried to remove unknown container: {container_id}".format(container_id = container_id))
             return
@@ -204,15 +215,17 @@ class LocalContainerProvider(ContainerProvider):
         except Exception:
             Logger.log("w", "Tried to delete file [%s], but it failed", path_to_delete)
 
-    ##  Load a pre-parsed definition container.
-    #
-    #   Definition containers can be quite expensive to load, so this loads a
-    #   pickled version of the definition if one is available.
-    #
-    #   \param definition_id The ID of the definition to load from the cache.
-    #   \return If a cached version was available, return it. If not, return
-    #   ``None``.
     def _loadCachedDefinition(self, definition_id) -> Optional[DefinitionContainer]:
+        """Load a pre-parsed definition container.
+        
+        Definition containers can be quite expensive to load, so this loads a
+        pickled version of the definition if one is available.
+        
+        :param definition_id: The ID of the definition to load from the cache.
+        :return: If a cached version was available, return it. If not, return
+                 ``None``.
+        """
+
         definition_path = self._id_to_path[definition_id]
         try:
             cache_path = Resources.getPath(Resources.Cache, "definitions", Application.getInstance().getVersion(), definition_id)
@@ -244,13 +257,15 @@ class LocalContainerProvider(ContainerProvider):
 
         return definition
 
-    ##  Cache a definition container on disk.
-    #
-    #   Definition containers can be quite expensive to parse and load, so this
-    #   pickles a container and saves the pre-parsed definition on disk.
-    #
-    #   \param definition The definition container to store.
     def _saveCachedDefinition(self, definition: DefinitionContainer) -> None:
+        """Cache a definition container on disk.
+        
+        Definition containers can be quite expensive to parse and load, so this
+        pickles a container and saves the pre-parsed definition on disk.
+        
+        :param definition: The definition container to store.
+        """
+
         cache_path = Resources.getStoragePath(Resources.Cache, "definitions", Application.getInstance().getVersion(), definition.id)
 
         # Ensure the cache path exists.
@@ -272,10 +287,12 @@ class LocalContainerProvider(ContainerProvider):
             if os.path.exists(cache_path):
                 os.remove(cache_path)  # The pickling might be half-complete, which causes EOFError in Pickle when you load it later.
 
-    ##  Updates the cache of paths to containers.
-    #
-    #   This way we can more easily load the container files we want lazily.
     def _updatePathCache(self) -> None:
+        """Updates the cache of paths to containers.
+        
+        This way we can more easily load the container files we want lazily.
+        """
+
         self._id_to_path = {}  # Clear cache first.
         self._id_to_mime = {}
 
@@ -297,11 +314,13 @@ class LocalContainerProvider(ContainerProvider):
             self._id_to_path[container_id] = filename
             self._id_to_mime[container_id] = mime
 
-    ##  Converts a file path to the MIME type of the container it represents.
-    #
-    #   \return The MIME type or None if it's not a container.
     @staticmethod
     def _pathToMime(path: str) -> Optional[MimeType]:
+        """Converts a file path to the MIME type of the container it represents.
+        
+        :return: The MIME type or None if it's not a container.
+        """
+
         try:
             mime = MimeTypeDatabase.getMimeTypeForFile(path)
         except MimeTypeDatabase.MimeTypeNotFoundError:
@@ -311,9 +330,10 @@ class LocalContainerProvider(ContainerProvider):
             return None
         return mime
 
-    ##  Converts a file path to the ID of the container it represents.
     @staticmethod
     def _pathToId(path: str) -> Optional[str]:
+        """Converts a file path to the ID of the container it represents."""
+
         result = None
         mime = LocalContainerProvider._pathToMime(path)
         if mime:
