@@ -1,16 +1,16 @@
 # Copyright (c) 2015 Ultimaker B.V.
 # Uranium is released under the terms of the LGPLv3 or higher.
 
-from UM.Scene.ToolHandle import ToolHandle
-from UM.Mesh.MeshBuilder import MeshBuilder
-from UM.Math.Vector import Vector
-
 import math
 
-##  Provides the circular toolhandles for each axis for the rotate tool
+from UM.Math.Vector import Vector
+from UM.Mesh.MeshBuilder import MeshBuilder
+from UM.Scene.ToolHandle import ToolHandle
 
 
 class RotateToolHandle(ToolHandle):
+    """Provides the circular toolhandles for each axis for the rotate tool"""
+
     def __init__(self, parent = None):
         super().__init__(parent)
 
