@@ -1,23 +1,24 @@
 # Copyright (c) 2015 Ultimaker B.V.
 # Uranium is released under the terms of the LGPLv3 or higher.
 
-from UM.Event import MouseEvent, KeyEvent
-from UM.Tool import Tool
-from UM.Application import Application
-from UM.Scene.Selection import Selection
-from UM.Scene.Iterator.BreadthFirstIterator import BreadthFirstIterator
-
-from UM.Logger import Logger
-
 from PyQt5 import QtCore, QtWidgets
 
+from UM.Application import Application
+from UM.Event import MouseEvent
+from UM.Logger import Logger
+from UM.Scene.Iterator.BreadthFirstIterator import BreadthFirstIterator
+from UM.Scene.Selection import Selection
+from UM.Tool import Tool
+
 
-##  Provides the tool to select meshes and groups
-#
-#   Note that the tool has two implementations for different modes of selection:
-#   Pixel Selection Mode and BoundingBox Selection Mode. Of these two, only Pixel Selection Mode
-#   is in active use. BoundingBox Selection Mode may not be functional.
 class SelectionTool(Tool):
+    """Provides the tool to select meshes and groups
+    
+    Note that the tool has two implementations for different modes of selection:
+    Pixel Selection Mode and BoundingBox Selection Mode. Of these two, only Pixel Selection Mode
+    is in active use. BoundingBox Selection Mode may not be functional.
+    """
+
     PixelSelectionMode = 1
     BoundingBoxSelectionMode = 2
 
@@ -34,32 +35,40 @@ class SelectionTool(Tool):
         self._alt_is_active = None
         self._shift_is_active = None  # Shift modifier key is used for multi-selection
 
-    ##  Prepare modifier-key variables on each event
-    #
-    #   \param event type(Event) event passed from event handler
     def checkModifierKeys(self, event):
+        """Prepare modifier-key variables on each event
+        
+        :param event: type(Event) event passed from event handler
+        """
+
         modifiers = QtWidgets.QApplication.keyboardModifiers()
         self._shift_is_active = modifiers & QtCore.Qt.ShiftModifier
         self._ctrl_is_active = modifiers & QtCore.Qt.ControlModifier
         self._alt_is_active = modifiers & QtCore.Qt.AltModifier
 
-    ##  Set the selection mode
-    #
-    #   The tool has two implementations for different modes of selection: PixelSelectionMode and BoundingboxSelectionMode.
-    #   Of these two, only Pixel Selection Mode is in active use. BoundingBox Selection Mode may not be functional.
-    #   \param mode type(SelectionTool enum)
     def setSelectionMode(self, mode):
+        """Set the selection mode
+        
+        The tool has two implementations for different modes of selection: PixelSelectionMode and BoundingboxSelectionMode.
+        Of these two, only Pixel Selection Mode is in active use. BoundingBox Selection Mode may not be functional.
+        :param mode: type(SelectionTool enum)
+        """
+
         self._selection_mode = mode
 
-    ##  Handle mouse and keyboard events
-    #
-    #   \param event type(Event)
     def event(self, event):
+        """Handle mouse and keyboard events
+        
+        :param event: type(Event)
+        """
+
         # The selection renderpass is used to identify objects in the current view
         if self._selection_pass is None:
             self._selection_pass = self._renderer.getRenderPass("selection")
 
         self.checkModifierKeys(event)
+        #if event.type == MouseEvent.MouseMoveEvent and Selection.getFaceSelectMode():
+        #    return self._pixelHover(event)
         if event.type == MouseEvent.MousePressEvent and MouseEvent.LeftButton in event.buttons and self._controller.getToolsEnabled():
             # Perform a selection operation
             if self._selection_mode == self.PixelSelectionMode:
@@ -70,10 +79,12 @@ class SelectionTool(Tool):
             Application.getInstance().getController().toolOperationStopped.emit(self)
         return False
 
-    ##  Handle mouse and keyboard events for bounding box selection
-    #
-    #   \param event type(Event) passed from self.event()
     def _boundingBoxSelection(self, event):
+        """Handle mouse and keyboard events for bounding box selection
+        
+        :param event: type(Event) passed from self.event()
+        """
+
         root = self._scene.getRoot()
 
         ray = self._scene.getActiveCamera().getRay(event.x, event.y)
@@ -96,19 +107,25 @@ class SelectionTool(Tool):
         else:
             Selection.clear()
 
-    ##  Handle mouse and keyboard events for pixel selection
-    #
-    #   \param event type(Event) passed from self.event()
     def _pixelSelection(self, event):
+        """Handle mouse and keyboard events for pixel selection
+        
+        :param event: type(Event) passed from self.event()
+        """
+
         # Find a node id by looking at a pixel value at the requested location
         if self._selection_pass:
-            item_id = self._selection_pass.getIdAtPosition(event.x, event.y)
+            if Selection.getFaceSelectMode():
+                item_id = id(Selection.getSelectedObject(0))
+            else:
+                item_id = self._selection_pass.getIdAtPosition(event.x, event.y)
         else:
             Logger.log("w", "Selection pass is None. getRenderPass('selection') returned None")
             return False
 
         if not item_id and not self._shift_is_active:
             if Selection.hasSelection():
+                Selection.clearFace()
                 Selection.clear()
                 return True
             return False  # Nothing was selected before and the user didn't click on an object.
@@ -141,6 +158,13 @@ class SelectionTool(Tool):
                             Selection.add(self._findTopGroupNode(node))
                         return True
             else:
+                if Selection.getFaceSelectMode():
+                    face_id = self._selection_pass.getFaceIdAtPosition(event.x, event.y)
+                    if face_id >= 0:
+                        Selection.toggleFace(node, face_id)
+                    else:
+                        Selection.clear()
+                        Selection.clearFace()
                 if not is_selected or Selection.getCount() > 1:
                     # Select only the SceneNode and its siblings in a group
                     Selection.clear()
@@ -157,21 +181,35 @@ class SelectionTool(Tool):
 
         return False
 
-    ##  Check whether a node is in a group
-    #
-    #   \param node type(SceneNode)
-    #   \return in_group type(boolean)
+    def _pixelHover(self, event):
+        if Selection.getFaceSelectMode():
+            face_id = self._selection_pass.getFaceIdAtPosition(event.x, event.y)
+            if face_id >= 0:
+                Selection.hoverFace(Selection.getSelectedObject(0), face_id)
+            else:
+                Selection.clearFace()
+            return True
+        return False
+
     def _isNodeInGroup(self, node):
+        """Check whether a node is in a group
+        
+        :param node: type(SceneNode)
+        :return: in_group type(boolean)
+        """
+
         parent_node = node.getParent()
         if not parent_node:
             return False
         return parent_node.callDecoration("isGroup")
 
-    ##  Get the top root group for a node
-    #
-    #   \param node type(SceneNode)
-    #   \return group type(SceneNode)
     def _findTopGroupNode(self, node):
+        """Get the top root group for a node
+        
+        :param node: type(SceneNode)
+        :return: group type(SceneNode)
+        """
+
         group_node = node
         while group_node.getParent().callDecoration("isGroup"):
             group_node = group_node.getParent()
